"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
import PyQt6.sip
from PyQt6 import QtCore
from PyQt6.QtQml import *
import enum


class QJSEngine(QtCore.QObject):
    """
    https://doc.qt.io/qt-6/qjsengine.html

    **Detailed Description**

    **Evaluating Scripts**

    Use **evaluate** () to evaluate script code.

    **QJSEngine**  myEngine;
        **QJSValue**  three = myEngine.evaluate("1 +
    2");

    **evaluate** () returns a **QJSValue**  that holds the result of the
    evaluation. The **QJSValue**  class provides functions for converting the
    result to various C++ types (e.g. **QJSValue::toString** () and
    **QJSValue::toNumber** ()).

    The following code snippet shows how a script function can be defined and
    then invoked from C++ using **QJSValue::call** ():

    **QJSValue**  fun = myEngine.evaluate("(function(a, b) { return a + b; })");
    **QJSValueList**  args;
        args << 1 << 2;
        **QJSValue**  threeAgain =
    fun.call(args);

    As can be seen from the above snippets, a script is provided to the engine
    in the form of a string. One common way of loading scripts is by reading the
    contents of a file and passing it to **evaluate** ():

    **QString**  fileName = "helloworld.qs";
        **QFile**
    scriptFile(fileName);
        if (!scriptFile.open(**QIODevice** ::ReadOnly))
    // handle error
        **QTextStream**  stream(&scriptFile);
        **QString**
    contents = stream.readAll();
        scriptFile.close();
    myEngine.evaluate(contents, fileName);

    Here we pass the name of the file as the second argument to **evaluate** ().
    This does not affect evaluation in any way; the second argument is a
    general-purpose string that is stored in the `Error` object for debugging
    purposes.

    For larger pieces of functionality, you may want to encapsulate your code
    and data into modules. A module is a file that contains script code,
    variables, etc., and uses export statements to describe its interface
    towards the rest of the application. With the help of import statements, a
    module can refer to functionality from other modules. This allows building a
    scripted application from smaller connected building blocks in a safe way.
    In contrast, the approach of using **evaluate** () carries the risk that
    internal variables or functions from one **evaluate** () call accidentally
    pollute the global object and affect subsequent evaluations.

    The following example provides a module that can add numbers:

    export function sum(left, right)
        {
            return left + right
        }

    This module can be loaded with QJSEngine::import() if it is saved under the
    name `math.mjs`:

    QJSvalue module = myEngine.importModule("./math.mjs");
        **QJSValue**
    sumFunction = module.property("sum");
        **QJSValue**  result =
    sumFunction.call(args);

    Modules can also use functionality from other modules using import
    statements:

    import { sum } from "./math.mjs";
        export function addTwice(left, right)
    {
            return sum(left, right) * 2;
        }

    Modules don't have to be files. They can be values registered with
    **QJSEngine::registerModule** ():

    import version from "version";

        export function getVersion()
        {
    return version;
        }

    **QJSValue**  version(610);
        myEngine.registerModule("version", version);
    **QJSValue**  module = myEngine.importModule("./myprint.mjs");
    **QJSValue**  getVersion = module.property("getVersion");
        **QJSValue**
    result = getVersion.call();

    Named exports are supported, but because they are treated as members of an
    object, the default export must be an ECMAScript object. Most of the newXYZ
    functions in **QJSValue**  will return an object.

    **QJSValue**  name("Qt6");
        **QJSValue**  obj = myEngine.newObject();
    obj.setProperty("name", name);
        myEngine.registerModule("info", obj);

    import { name } from "info";

        export function getName()
        {
    return name;
        }

    **Engine Configuration**

    The **globalObject** () function returns the **Global Object** associated
    with the script engine. Properties of the Global Object are accessible from
    any script code (i.e. they are global variables). Typically, before
    evaluating "user" scripts, you will want to configure a script engine by
    adding one or more properties to the Global Object:

    myEngine.globalObject().setProperty("myNumber", 123);
        ...
    **QJSValue**  myNumberPlusOne = myEngine.evaluate("myNumber + 1");

    Adding custom properties to the scripting environment is one of the standard
    means of providing a scripting API that is specific to your application.
    Usually these custom properties are objects created by the **newQObject** ()
    or **newObject** () functions.

    **Script Exceptions**

    **evaluate** () can throw a script exception (e.g. due to a syntax error).
    If it does, then **evaluate** () returns the value that was thrown
    (typically an `Error` object). Use **QJSValue::isError** () to check for
    exceptions.

    For detailed information about the error, use **QJSValue::toString** () to
    obtain an error message, and use **QJSValue::property** () to query the
    properties of the `Error` object. The following properties are available:

    * `name`
      * `message`
      * `fileName`
      * `lineNumber`
      * `stack`

    **QJSValue**  result = myEngine.evaluate(...);
        if (result.isError())
    **qDebug** ()
                    << "Uncaught exception at line"
    << result.property("lineNumber").toInt()
                    << ":" <<
    result.toString();

    **Script Object Creation**

    Use **newObject** () to create a JavaScript object; this is the C++
    equivalent of the script statement `new Object()`. You can use the object-
    specific functionality in **QJSValue**  to manipulate the script object
    (e.g. **QJSValue::setProperty** ()). Similarly, use **newArray** () to
    create a JavaScript array object.

    **QObject Integration**

    Use **newQObject** () to wrap a **QObject**  (or subclass) pointer.
    **newQObject** () returns a proxy script object; properties, children, and
    signals and slots of the **QObject**  are available as properties of the
    proxy object. No binding code is needed because it is done dynamically using
    the Qt meta object system.

    **QPushButton**  *button = new **QPushButton** ;
        **QJSValue**
    scriptButton = myEngine.newQObject(button);
    myEngine.globalObject().setProperty("button", scriptButton);
    myEngine.evaluate("button.checkable = true");

        **qDebug** () <<
    scriptButton.property("checkable").toBool();
    scriptButton.property("show").call(); // call the show() slot

    Use **newQMetaObject** () to wrap a **QMetaObject** ; this gives you a
    "script representation" of a **QObject** -based class. **newQMetaObject** ()
    returns a proxy script object; enum values of the class are available as
    properties of the proxy object.

    Constructors exposed to the meta-object system (using **Q_INVOKABLE** ) can
    be called from the script to create a new **QObject**  instance with
    **JavaScriptOwnership** . For example, given the following class definition:

    class MyObject : public **QObject**
        {
            Q_OBJECT

        public:
    Q_INVOKABLE MyObject() {}
        };

    The `staticMetaObject` for the class can be exposed to JavaScript like so:

    **QJSValue**  jsMetaObject =
    engine.newQMetaObject(&MyObject::staticMetaObject);
    engine.globalObject().setProperty("MyObject", jsMetaObject);

    Instances of the class can then be created in JavaScript:

    engine.evaluate("var myObject = new MyObject()");

    **Note:** Currently only classes using the **Q_OBJECT**  macro are
    supported; it is not possible to expose the `staticMetaObject` of a
    **Q_GADGET**  class to JavaScript.

    **Dynamic QObject Properties**

    Dynamic **QObject**  properties are not supported. For example, the
    following code will not work:

    **QJSEngine**  engine;

        **QObject**  *myQObject = new **QObject**
    ();
        myQObject->setProperty("dynamicProperty", 3);

        **QJSValue**
    myScriptQObject = engine.newQObject(myQObject);
    engine.globalObject().setProperty("myObject", myScriptQObject);
    **qDebug** () << engine.evaluate("myObject.dynamicProperty").toInt();

    **Extensions**

    QJSEngine provides a compliant ECMAScript implementation. By default,
    familiar utilities like logging are not available, but they can can be
    installed via the **installExtensions** () function.

    **See also** **QJSValue** , **Making Applications Scriptable** , and **List
    of JavaScript Objects and Functions** .
    """

    class ObjectOwnership(enum.Enum):
        CppOwnership: QJSEngine = ...
        JavaScriptOwnership: QJSEngine = ...

    class Extension(enum.Flag):
        TranslationExtension: QJSEngine = ...
        ConsoleExtension: QJSEngine = ...
        GarbageCollectionExtension: QJSEngine = ...
        AllExtensions: QJSEngine = ...

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qjsengine.html#QJSEngine

        **QJSEngine::QJSEngine()**

        Constructs a QJSEngine object.

        The **globalObject** () is initialized to have properties as described
        in **ECMA-262** , Section 15.1.
        """
        ...

    @typing.overload
    def __init__(self, parent: QtCore.QObject) -> None:
        """
        https://doc.qt.io/qt-6/qjsengine.html#QJSEngine-1

        **QJSEngine::QJSEngine(QObject * parent )**

        Constructs a QJSEngine object with the given **parent**.

        The **globalObject** () is initialized to have properties as described
        in **ECMA-262** , Section 15.1.
        """
        ...

    def newSymbol(self, name: str) -> "QJSValue":
        """
        https://doc.qt.io/qt-6/qjsengine.html#newSymbol

        **[since 6.2] QJSValue QJSEngine::newSymbol(const QString & name )**

        Creates a JavaScript object of class Symbol, with value **name**.

        The prototype of the created object will be the Symbol prototype object.

        This function was introduced in Qt 6.2.

        **See also** **newObject** ().
        """
        ...

    def registerModule(
        self,
        moduleName: str,
        value: typing.Union["QJSValue", "QJSValue.SpecialValue", bool, int, float, str],
    ) -> bool:
        """
        https://doc.qt.io/qt-6/qjsengine.html#registerModule

        **bool QJSEngine::registerModule(const QString & moduleName , const
        QJSValue & value )**

        Registers a **QJSValue**  to serve as a module. After this function is
        called, all modules that import **moduleName** will import the value of
        **value** instead of loading **moduleName** from the filesystem.

        Any valid **QJSValue**  can be registered, but named exports (i.e.
        `import { name } from "info"` are treated as members of an object, so
        the default export must be created with one of the newXYZ methods of
        **QJSEngine** .

        Because this allows modules that do not exist on the filesystem to be
        imported, scripting applications can use this to provide built-in
        modules, similar to Node.js.

        Returns `true` on success, `false` otherwise.

        **Note:** The **QJSValue**  **value** is not called or read until it is
        used by another module. This means that there is no code to evaluate, so
        no errors will be seen until another module throws an exception while
        trying to load this module.

        **Warning:** Attempting to access a named export from a **QJSValue**
        that is not an object will trigger a **exception** .

        **See also** **importModule** ().
        """
        ...

    def catchError(self) -> "QJSValue":
        """
        https://doc.qt.io/qt-6/qjsengine.html#catchError

        **[since Qt 6.1] QJSValue QJSEngine::catchError()**

        If an exception is currently pending, catches it and returns it as a
        **QJSValue** . Otherwise returns undefined as **QJSValue** . After
        calling this method **hasError** () returns `false`.

        This function was introduced in Qt 6.1.
        """
        ...

    def hasError(self) -> bool:
        """
        https://doc.qt.io/qt-6/qjsengine.html#hasError

        **[since Qt 6.1] bool QJSEngine::hasError() const**

        Returns `true` if the last JavaScript execution resulted in an exception
        or if **throwError** () was called. Otherwise returns `false`. Mind that
        **evaluate** () catches any exceptions thrown in the evaluated code.

        This function was introduced in Qt 6.1.
        """
        ...

    @staticmethod
    def objectOwnership(a0: QtCore.QObject) -> "QJSEngine.ObjectOwnership":
        """
        https://doc.qt.io/qt-6/qjsengine.html#objectOwnership

        **[static] QJSEngine::ObjectOwnership QJSEngine::objectOwnership(QObject
        * object )**

        Returns the ownership of **object**.

        **See also** **setObjectOwnership** () and
        **QJSEngine::ObjectOwnership** .
        """
        ...

    @staticmethod
    def setObjectOwnership(a0: QtCore.QObject, a1: "QJSEngine.ObjectOwnership") -> None:
        """
        https://doc.qt.io/qt-6/qjsengine.html#setObjectOwnership

        **[static] void QJSEngine::setObjectOwnership(QObject * object ,
        QJSEngine::ObjectOwnership ownership )**

        Sets the **ownership** of **object**.

        An object with `JavaScriptOwnership` is not garbage collected as long as
        it still has a parent, even if there are no references to it.

        **See also** **objectOwnership** () and **QJSEngine::ObjectOwnership** .
        """
        ...

    def setUiLanguage(self, language: str) -> None:
        """
        https://doc.qt.io/qt-6/qjsengine.html#uiLanguage-prop

        **[since 5.15] uiLanguage : QString**

        This property holds the language to be used for translating user
        interface strings

        This property holds the name of the language to be used for user
        interface string translations. It is exposed for reading and writing as
        `Qt.uiLanguage` when the **QJSEngine::TranslationExtension**  is
        installed on the engine. It is always exposed in instances of
        **QQmlEngine** .

        You can set the value freely and use it in bindings. It is recommended
        to set it after installing translators in your application. By
        convention, an empty string means no translation from the language used
        in the source code is intended to occur.

        This property was introduced in Qt 5.15.

        **Access functions:**

        QString **uiLanguage** () const
        void **setUiLanguage** (const QString
        & **language** )

        **Notifier signal:**

        void **uiLanguageChanged** ()

        **Member Function Documentation**
        """
        ...

    def uiLanguage(self) -> str:
        """
        https://doc.qt.io/qt-6/qjsengine.html#uiLanguage-prop

        **[since 5.15] uiLanguage : QString**

        This property holds the language to be used for translating user
        interface strings

        This property holds the name of the language to be used for user
        interface string translations. It is exposed for reading and writing as
        `Qt.uiLanguage` when the **QJSEngine::TranslationExtension**  is
        installed on the engine. It is always exposed in instances of
        **QQmlEngine** .

        You can set the value freely and use it in bindings. It is recommended
        to set it after installing translators in your application. By
        convention, an empty string means no translation from the language used
        in the source code is intended to occur.

        This property was introduced in Qt 5.15.

        **Access functions:**

        QString **uiLanguage** () const
        void **setUiLanguage** (const QString
        & **language** )

        **Notifier signal:**

        void **uiLanguageChanged** ()

        **Member Function Documentation**
        """
        ...

    def isInterrupted(self) -> bool:
        """
        https://doc.qt.io/qt-6/qjsengine.html#isInterrupted

        **[since 5.14] bool QJSEngine::isInterrupted() const**

        Returns whether JavaScript execution is currently interrupted.

        This function was introduced in Qt 5.14.

        **See also** **setInterrupted** ().
        """
        ...

    def setInterrupted(self, interrupted: bool) -> None:
        """
        https://doc.qt.io/qt-6/qjsengine.html#setInterrupted

        **[since 5.14] void QJSEngine::setInterrupted(bool interrupted )**

        Interrupts or re-enables JavaScript execution.

        If **interrupted** is `true`, any JavaScript executed by this engine
        immediately aborts and returns an error object until this function is
        called again with a value of `false` for **interrupted**.

        This function is thread safe. You may call it from a different thread in
        order to interrupt, for example, an infinite loop in JavaScript.

        This function was introduced in Qt 5.14.

        **See also** **isInterrupted** ().
        """
        ...

    @typing.overload
    def throwError(self, message: str) -> None:
        """
        https://doc.qt.io/qt-6/qjsengine.html#throwError

        **[since Qt 5.12] void QJSEngine::throwError(const QString & message )**

        Throws a run-time error (exception) with the given **message**.

        This method is the C++ counterpart of a `throw()` expression in
        JavaScript. It enables C++ code to report run-time errors to
        **QJSEngine** . Therefore it should only be called from C++ code that
        was invoked by a JavaScript function through **QJSEngine** .

        When returning from C++, the engine will interrupt the normal flow of
        execution and call the the next pre-registered exception handler with an
        error object that contains the given **message**. The error object will
        point to the location of the top-most context on the JavaScript caller
        stack; specifically, it will have properties `lineNumber`, `fileName`
        and `stack`. These properties are described in **Script Exceptions** .

        In the following example a C++ method in **FileAccess.cpp** throws an
        error in **qmlFile.qml** at the position where `readFileAsText()` is
        called:

        // qmlFile.qml
            function someFunction() {
              ...
              var text =
        FileAccess.readFileAsText("/path/to/file.txt");
            }

        // FileAccess.cpp
            // Assuming that FileAccess is a QObject-derived
        class that has been
            // registered as a singleton type and provides
        an invokable method
            // readFileAsText()

            **QJSValue**
        FileAccess::readFileAsText(const **QString**  & filePath) {
        **QFile**  file(filePath);

              if (!file.open(**QIODevice**
        ::ReadOnly)) {
                jsEngine->throwError(file.errorString());
        return **QString** ();
              }

              ...
              return content;
        }

        It is also possible to catch the thrown error in JavaScript:

        // qmlFile.qml
            function someFunction() {
              ...
              var text;
        try {
                text = FileAccess.readFileAsText("/path/to/file.txt");
        } catch (error) {
                console.warn("In " + error.fileName + ":" +
        "error.lineNumber" +
                             ": " + error.message);
              }
        }

        If you need a more specific run-time error to describe an exception, you
        can use the **throwError** (QJSValue::ErrorType errorType, const QString
        &message) overload.

        This function was introduced in Qt 5.12.

        **See also** **Script Exceptions** .
        """
        ...

    @typing.overload
    def throwError(
        self,
        error: typing.Union["QJSValue", "QJSValue.SpecialValue", bool, int, float, str],
    ) -> None:
        """
        https://doc.qt.io/qt-6/qjsengine.html#throwError-1

        **[since Qt 5.12] void QJSEngine::throwError(QJSValue::ErrorType
        errorType , const QString & message = QString())**

        This function overloads throwError().

        Throws a run-time error (exception) with the given **errorType** and
        **message**.

        // Assuming that DataEntry is a QObject-derived class that has been
        // registered as a singleton type and provides an invokable method
        // setAge().

            void DataEntry::setAge(int age) {
              if (age <
        0 || age > 200) {
                jsEngine->throwError(**QJSValue**
        ::RangeError,
                                     "Age must be between 0 and
        200");
              }
              ...
            }

        This function was introduced in Qt 5.12.

        **See also** **Script Exceptions**  and **newErrorObject** ().
        """
        ...

    @typing.overload
    def throwError(self, errorType: "QJSValue.ErrorType", message: str = ...) -> None:
        """
        https://doc.qt.io/qt-6/qjsengine.html#throwError-2

        **[since 6.1] void QJSEngine::throwError(const QJSValue & error )**

        This function overloads throwError().

        Throws a pre-constructed run-time **error** (exception). This way you
        can use **newErrorObject** () to create the error and customize it as
        necessary.

        This function was introduced in Qt 6.1.

        **See also** **Script Exceptions**  and **newErrorObject** ().
        """
        ...

    def newErrorObject(
        self, errorType: "QJSValue.ErrorType", message: str = ...
    ) -> "QJSValue":
        """
        https://doc.qt.io/qt-6/qjsengine.html#newErrorObject

        **[since 5.12] QJSValue QJSEngine::newErrorObject(QJSValue::ErrorType
        errorType , const QString & message = QString())**

        Creates a JavaScript object of class Error, with **message** as the
        error message.

        The prototype of the created object will be **errorType**.

        This function was introduced in Qt 5.12.

        **See also** **newObject** (), **throwError** (), and
        **QJSValue::isError** ().
        """
        ...

    def importModule(self, fileName: str) -> "QJSValue":
        """
        https://doc.qt.io/qt-6/qjsengine.html#importModule

        **[since 5.12] QJSValue QJSEngine::importModule(const QString & fileName
        )**

        Imports the module located at **fileName** and returns a module
        namespace object that contains all exported variables, constants and
        functions as properties.

        If this is the first time the module is imported in the engine, the file
        is loaded from the specified location in either the local file system or
        the Qt resource system and evaluated as an ECMAScript module. The file
        is expected to be encoded in UTF-8 text.

        Subsequent imports of the same module will return the previously
        imported instance. Modules are singletons and remain around until the
        engine is destroyed.

        The specified **fileName** will internally be normalized using
        **QFileInfo::canonicalFilePath** (). That means that multiple imports of
        the same file on disk using different relative paths will load the file
        only once.

        **Note:** If an exception is thrown during the loading of the module,
        the return value will be the exception (typically an `Error` object; see
        **QJSValue::isError** ()).

        This function was introduced in Qt 5.12.

        **See also** **registerModule** ().
        """
        ...

    def newQMetaObject(self, metaObject: QtCore.QMetaObject) -> "QJSValue":
        """
        https://doc.qt.io/qt-6/qjsengine.html#newQMetaObject

        **[since 5.8] QJSValue QJSEngine::newQMetaObject(const QMetaObject *
        metaObject )**

        Creates a JavaScript object that wraps the given **QMetaObject**  The
        **metaObject** must outlive the script engine. It is recommended to only
        use this method with static metaobjects.

        When called as a constructor, a new instance of the class will be
        created. Only constructors exposed by **Q_INVOKABLE**  will be visible
        from the script engine.

        This function was introduced in Qt 5.8.

        **See also** **newQObject** () and **QObject Integration** .
        """
        ...

    def installExtensions(
        self,
        extensions: "QJSEngine.Extension",
        object: typing.Union[
            "QJSValue", "QJSValue.SpecialValue", bool, int, float, str
        ] = ...,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qjsengine.html#installExtensions

        **[since 5.6] void QJSEngine::installExtensions(QJSEngine::Extensions
        extensions , const QJSValue & object = QJSValue())**

        Installs JavaScript **extensions** to add functionality that is not
        available in a standard ECMAScript implementation.

        The extensions are installed on the given **object** , or on the
        **Global Object**  if no object is specified.

        Several extensions can be installed at once by `OR`-ing the enum values:

        installExtensions(**QJSEngine** ::TranslationExtension | **QJSEngine**
        ::ConsoleExtension);

        This function was introduced in Qt 5.6.

        **See also** **Extension** .
        """
        ...

    def collectGarbage(self) -> None:
        """
        https://doc.qt.io/qt-6/qjsengine.html#collectGarbage

        **void QJSEngine::collectGarbage()**

        Runs the garbage collector.

        The garbage collector will attempt to reclaim memory by locating and
        disposing of objects that are no longer reachable in the script
        environment.

        Normally you don't need to call this function; the garbage collector
        will automatically be invoked when the **QJSEngine**  decides that it's
        wise to do so (i.e. when a certain number of new objects have been
        created). However, you can call this function to explicitly request that
        garbage collection should be performed as soon as possible.
        """
        ...

    def newQObject(self, object: QtCore.QObject) -> "QJSValue":
        """
        https://doc.qt.io/qt-6/qjsengine.html#newQObject

        **QJSValue QJSEngine::newQObject(QObject * object )**

        Creates a JavaScript object that wraps the given **QObject**  **object**
        , using **JavaScriptOwnership** .

        Signals and slots, properties and children of **object** are available
        as properties of the created **QJSValue** .

        If **object** is a null pointer, this function returns a null value.

        If a default prototype has been registered for the **object** 's class
        (or its superclass, recursively), the prototype of the new script object
        will be set to be that default prototype.

        If the given **object** is deleted outside of the engine's control, any
        attempt to access the deleted **QObject** 's members through the
        JavaScript wrapper object (either by script code or C++) will result in
        a **script exception** .

        **See also** **QJSValue::toQObject** ().
        """
        ...

    def newArray(self, length: int = ...) -> "QJSValue":
        """
        https://doc.qt.io/qt-6/qjsengine.html#newArray

        **QJSValue QJSEngine::newArray(uint length = 0)**

        Creates a JavaScript object of class Array with the given **length**.

        **See also** **newObject** ().
        """
        ...

    def newObject(self) -> "QJSValue":
        """
        https://doc.qt.io/qt-6/qjsengine.html#newObject

        **QJSValue QJSEngine::newObject()**

        Creates a JavaScript object of class Object.

        The prototype of the created object will be the Object prototype object.

        **See also** **newArray** () and **QJSValue::setProperty** ().
        """
        ...

    def evaluate(
        self,
        program: str,
        fileName: str = ...,
        lineNumber: int = ...,
        exceptionStackTrace: typing.Optional[typing.List[str]] = ...,
    ) -> "QJSValue":
        """
        https://doc.qt.io/qt-6/qjsengine.html#evaluate

        **QJSValue QJSEngine::evaluate(const QString & program , const QString &
        fileName = QString(), int lineNumber = 1, QStringList *
        exceptionStackTrace = nullptr)**

        Evaluates **program** , using **lineNumber** as the base line number,
        and returns the result of the evaluation.

        The script code will be evaluated in the context of the global object.

        The evaluation of **program** can cause an **exception**  in the engine;
        in this case the return value will be the exception that was thrown
        (typically an `Error` object; see **QJSValue::isError** ()).

        **lineNumber** is used to specify a starting line number for **program**
        ; line number information reported by the engine that pertains to this
        evaluation will be based on this argument. For example, if **program**
        consists of two lines of code, and the statement on the second line
        causes a script exception, the exception line number would be
        **lineNumber** plus one. When no starting line number is specified, line
        numbers will be 1-based.

        **fileName** is used for error reporting. For example, in error objects
        the file name is accessible through the "fileName" property if it is
        provided with this function.

        **exceptionStackTrace** is used to report whether an uncaught exception
        was thrown. If you pass a non-null pointer to a **QStringList**  to it,
        it will set it to list of "stackframe messages" if the script threw an
        unhandled exception, or an empty list otherwise. A stackframe message
        has the format function name:line number:column:file name

        **Note:** In some cases, e.g. for native functions, function name and
        file name can be empty and line number and column can be -1.

        **Note:** If an exception was thrown and the exception value is not an
        Error instance (i.e., **QJSValue::isError** () returns `false`), the
        exception value will still be returned. Use
        `exceptionStackTrace->isEmpty()` to distinguish whether the value was a
        normal or an exceptional return value.
        """
        ...

    def globalObject(self) -> "QJSValue":
        """
        https://doc.qt.io/qt-6/qjsengine.html#globalObject

        **QJSValue QJSEngine::globalObject() const**

        Returns this engine's Global Object.

        By default, the Global Object contains the built-in objects that are
        part of **ECMA-262** , such as Math, Date and String. Additionally, you
        can set properties of the Global Object to make your own extensions
        available to all script code. Non-local variables in script code will be
        created as properties of the Global Object, as well as local variables
        in global code.
        """
        ...

    @property
    def uiLanguageChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
import PyQt6.sip
from PyQt6 import QtCore
from PyQt6.QtGui import *
import enum


class QImageReader(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qimagereader.html

    **Detailed Description**

    The most common way to read images is through **QImage**  and **QPixmap** 's
    constructors, or by calling **QImage::load** () and **QPixmap::load** ().
    QImageReader is a specialized class which gives you more control when
    reading images. For example, you can read an image into a specific size by
    calling **setScaledSize** (), and you can select a clip rect, effectively
    loading only parts of an image, by calling **setClipRect** (). Depending on
    the underlying support in the image format, this can save memory and speed
    up loading of images.

    To read an image, you start by constructing a QImageReader object. Pass
    either a file name or a device pointer, and the image format to
    QImageReader's constructor. You can then set several options, such as the
    clip rect (by calling **setClipRect** ()) and scaled size (by calling
    **setScaledSize** ()). **canRead** () returns the image if the QImageReader
    can read the image (i.e., the image format is supported and the device is
    open for reading). Call **read** () to read the image.

    If any error occurs when reading the image, **read** () will return a null
    **QImage** . You can then call **error** () to find the type of error that
    occurred, or **errorString** () to get a human readable description of what
    went wrong.

    **Note:** QImageReader assumes exclusive control over the file or device
    that is assigned. Any attempts to modify the assigned file or device during
    the lifetime of the QImageReader object will yield undefined results.

    **Formats**

    Call **supportedImageFormats** () for a list of formats that QImageReader
    can read. QImageReader supports all built-in image formats, in addition to
    any image format plugins that support reading. Call **supportedMimeTypes**
    () to obtain a list of supported MIME types, which for example can be passed
    to **QFileDialog::setMimeTypeFilters** ().

    QImageReader autodetects the image format by default, by looking at the
    provided (optional) format string, the file name suffix, and the data stream
    contents. You can enable or disable this feature, by calling
    **setAutoDetectImageFormat** ().

    **High Resolution Versions of Images**

    It is possible to provide high resolution versions of images should a
    scaling between **device pixels** and **device independent pixels** be in
    effect.

    The high resolution version is marked by the suffix `@2x` on the base name.
    The image read will have its **device pixel ratio** set to a value of 2.

    This can be disabled by setting the environment variable
    `QT_HIGHDPI_DISABLE_2X_IMAGE_LOADING`.

    **See also** **QImageWriter** , **QImageIOHandler** , **QImageIOPlugin** ,
    **QMimeDatabase** , **QColorSpace** , **QImage::devicePixelRatio** (),
    **QPixmap::devicePixelRatio** (), **QIcon** , **QPainter::drawPixmap** (),
    and **QPainter::drawImage** ().
    """

    class ImageReaderError(enum.Enum):
        UnknownError: QImageReader = ...
        FileNotFoundError: QImageReader = ...
        DeviceError: QImageReader = ...
        UnsupportedFormatError: QImageReader = ...
        InvalidDataError: QImageReader = ...

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qimagereader.html#QImageReader

        **QImageReader::QImageReader()**

        Constructs an empty QImageReader object. Before reading an image, call
        **setDevice** () or **setFileName** ().
        """
        ...

    @typing.overload
    def __init__(
        self, device: QtCore.QIODevice, format: QtCore.QByteArray = ...
    ) -> None:
        """
        https://doc.qt.io/qt-6/qimagereader.html#QImageReader-1

        **QImageReader::QImageReader(QIODevice * device , const QByteArray &
        format = QByteArray())**

        Constructs a QImageReader object with the device **device** and the
        image format **format**.
        """
        ...

    @typing.overload
    def __init__(self, fileName: str, format: QtCore.QByteArray = ...) -> None:
        """
        https://doc.qt.io/qt-6/qimagereader.html#QImageReader-2

        **QImageReader::QImageReader(const QString & fileName , const QByteArray
        & format = QByteArray())**

        Constructs a QImageReader object with the file name **fileName** and the
        image format **format**.

        **See also** **setFileName** ().
        """
        ...

    @staticmethod
    def imageFormatsForMimeType(
        mimeType: QtCore.QByteArray,
    ) -> typing.List[QtCore.QByteArray]:
        """
        https://doc.qt.io/qt-6/qimagereader.html#imageFormatsForMimeType

        **[static, since 5.12] QList<QByteArray>
        QImageReader::imageFormatsForMimeType(const QByteArray & mimeType )**

        Returns the list of image formats corresponding to **mimeType**.

        Note that the **QGuiApplication**  instance must be created before this
        function is called.

        This function was introduced in Qt 5.12.

        **See also** **supportedImageFormats** () and **supportedMimeTypes** ().
        """
        ...

    def autoTransform(self) -> bool:
        """
        https://doc.qt.io/qt-6/qimagereader.html#autoTransform

        **[since 5.5] bool QImageReader::autoTransform() const**

        Returns `true` if the image handler will apply transformation metadata
        on **read** ().

        This function was introduced in Qt 5.5.

        **See also** **setAutoTransform** (), **transformation** (), and
        **read** ().
        """
        ...

    def setAutoTransform(self, enabled: bool) -> None:
        """
        https://doc.qt.io/qt-6/qimagereader.html#setAutoTransform

        **[since 5.5] void QImageReader::setAutoTransform(bool enabled )**

        Determines that images returned by **read** () should have
        transformation metadata automatically applied if **enabled** is `true`.

        This function was introduced in Qt 5.5.

        **See also** **autoTransform** (), **transformation** (), and **read**
        ().
        """
        ...

    def transformation(self) -> QImageIOHandler.Transformation:
        """
        https://doc.qt.io/qt-6/qimagereader.html#transformation

        **[since 5.5] QImageIOHandler::Transformations
        QImageReader::transformation() const**

        Returns the transformation metadata of the image, including image
        orientation. If the format does not support transformation metadata,
        **QImageIOHandler::TransformationNone**  is returned.

        This function was introduced in Qt 5.5.

        **See also** **setAutoTransform** () and **autoTransform** ().
        """
        ...

    def supportedSubTypes(self) -> typing.List[QtCore.QByteArray]:
        """
        https://doc.qt.io/qt-6/qimagereader.html#supportedSubTypes

        **[since 5.4] QList<QByteArray> QImageReader::supportedSubTypes()
        const**

        Returns the list of subtypes supported by an image.

        This function was introduced in Qt 5.4.
        """
        ...

    def subType(self) -> QtCore.QByteArray:
        """
        https://doc.qt.io/qt-6/qimagereader.html#subType

        **[since 5.4] QByteArray QImageReader::subType() const**

        Returns the subtype of the image.

        This function was introduced in Qt 5.4.
        """
        ...

    @staticmethod
    def supportedMimeTypes() -> typing.List[QtCore.QByteArray]:
        """
        https://doc.qt.io/qt-6/qimagereader.html#supportedMimeTypes

        **[static] QList<QByteArray> QImageReader::supportedMimeTypes()**

        Returns the list of MIME types supported by **QImageReader** .

        Note that the **QApplication**  instance must be created before this
        function is called.

        **See also** **supportedImageFormats** () and
        **QImageWriter::supportedMimeTypes** ().
        """
        ...

    def decideFormatFromContent(self) -> bool:
        """
        https://doc.qt.io/qt-6/qimagereader.html#decideFormatFromContent

        **bool QImageReader::decideFormatFromContent() const**

        Returns whether the image reader should decide which plugin to use only
        based on the contents of the datastream rather than on the file
        extension.

        **See also** **setDecideFormatFromContent** ().
        """
        ...

    def setDecideFormatFromContent(self, ignored: bool) -> None:
        """
        https://doc.qt.io/qt-6/qimagereader.html#setDecideFormatFromContent

        **void QImageReader::setDecideFormatFromContent(bool ignored )**

        If **ignored** is set to true, then the image reader will ignore
        specified formats or file extensions and decide which plugin to use only
        based on the contents in the datastream.

        Setting this flag means that all image plugins gets loaded. Each plugin
        will read the first bytes in the image data and decide if the plugin is
        compatible or not.

        This also disables auto detecting the image format.

        **See also** **decideFormatFromContent** ().
        """
        ...

    def autoDetectImageFormat(self) -> bool:
        """
        https://doc.qt.io/qt-6/qimagereader.html#autoDetectImageFormat

        **bool QImageReader::autoDetectImageFormat() const**

        Returns `true` if image format autodetection is enabled on this image
        reader; otherwise returns `false`. By default, autodetection is enabled.

        **See also** **setAutoDetectImageFormat** ().
        """
        ...

    def setAutoDetectImageFormat(self, enabled: bool) -> None:
        """
        https://doc.qt.io/qt-6/qimagereader.html#setAutoDetectImageFormat

        **void QImageReader::setAutoDetectImageFormat(bool enabled )**

        If **enabled** is true, image format autodetection is enabled;
        otherwise, it is disabled. By default, autodetection is enabled.

        **QImageReader**  uses an extensive approach to detecting the image
        format; firstly, if you pass a file name to **QImageReader** , it will
        attempt to detect the file extension if the given file name does not
        point to an existing file, by appending supported default extensions to
        the given file name, one at a time. It then uses the following approach
        to detect the image format:

        * Image plugins are queried first, based on either the optional format
        string, or the file name suffix (if the source device is a file). No
        content detection is done at this stage. **QImageReader**  will choose
        the first plugin that supports reading for this format.
          * If no plugin
        supports the image format, Qt's built-in handlers are checked based on
        either the optional format string, or the file name suffix.
          * If no
        capable plugins or built-in handlers are found, each plugin is tested by
        inspecting the content of the data stream.
          * If no plugins could
        detect the image format based on data contents, each built-in image
        handler is tested by inspecting the contents.
          * Finally, if all above
        approaches fail, **QImageReader**  will report failure when trying to
        read the image.

        By disabling image format autodetection, **QImageReader**  will only
        query the plugins and built-in handlers based on the format string
        (i.e., no file name extensions are tested).

        **See also** **autoDetectImageFormat** (), **QImageIOHandler::canRead**
        (), and **QImageIOPlugin::capabilities** ().
        """
        ...

    def supportsOption(self, option: QImageIOHandler.ImageOption) -> bool:
        """
        https://doc.qt.io/qt-6/qimagereader.html#supportsOption

        **bool QImageReader::supportsOption(QImageIOHandler::ImageOption option
        ) const**

        Returns `true` if the reader supports **option** ; otherwise returns
        false.

        Different image formats support different options. Call this function to
        determine whether a certain option is supported by the current format.
        For example, the PNG format allows you to embed text into the image's
        metadata (see **text** ()), and the BMP format allows you to determine
        the image's size without loading the whole image into memory (see
        **size** ()).

        **QImageReader**  reader(":/image.png");
            if
        (reader.supportsOption(**QImageIOHandler** ::Size))
                **qDebug**
        () << "Size:" << reader.size();

        **See also** **QImageWriter::supportsOption** ().
        """
        ...

    def quality(self) -> int:
        """
        https://doc.qt.io/qt-6/qimagereader.html#quality

        **int QImageReader::quality() const**

        Returns the quality setting of the image format.

        **See also** **setQuality** ().
        """
        ...

    def setQuality(self, quality: int) -> None:
        """
        https://doc.qt.io/qt-6/qimagereader.html#setQuality

        **void QImageReader::setQuality(int quality )**

        Sets the quality setting of the image format to **quality**.

        Some image formats, in particular lossy ones, entail a tradeoff between
        a) visual quality of the resulting image, and b) decoding execution
        time. This function sets the level of that tradeoff for image formats
        that support it.

        In case of scaled image reading, the quality setting may also influence
        the tradeoff level between visual quality and execution speed of the
        scaling algorithm.

        The value range of **quality** depends on the image format. For example,
        the "jpeg" format supports a quality range from 0 (low visual quality)
        to 100 (high visual quality).

        **See also** **quality** () and **setScaledSize** ().
        """
        ...

    def supportsAnimation(self) -> bool:
        """
        https://doc.qt.io/qt-6/qimagereader.html#supportsAnimation

        **bool QImageReader::supportsAnimation() const**

        Returns `true` if the image format supports animation; otherwise, false
        is returned.

        **See also** **QMovie::supportedFormats** ().
        """
        ...

    def backgroundColor(self) -> QColor:
        """
        https://doc.qt.io/qt-6/qimagereader.html#backgroundColor

        **QColor QImageReader::backgroundColor() const**

        Returns the background color that's used when reading an image. If the
        image format does not support setting the background color an invalid
        color is returned.

        **See also** **setBackgroundColor** () and **read** ().
        """
        ...

    def setBackgroundColor(
        self, color: typing.Union[QColor, QtCore.Qt.GlobalColor, int, QGradient]
    ) -> None:
        """
        https://doc.qt.io/qt-6/qimagereader.html#setBackgroundColor

        **void QImageReader::setBackgroundColor(const QColor & color )**

        Sets the background color to **color**. Image formats that support this
        operation are expected to initialize the background to **color** before
        reading an image.

        **See also** **backgroundColor** () and **read** ().
        """
        ...

    def text(self, key: str) -> str:
        """
        https://doc.qt.io/qt-6/qimagereader.html#text

        **QString QImageReader::text(const QString & key ) const**

        Returns the image text associated with **key**.

        Support for this option is implemented through
        **QImageIOHandler::Description** .

        **See also** **textKeys** () and **QImageWriter::setText** ().
        """
        ...

    def textKeys(self) -> typing.List[str]:
        """
        https://doc.qt.io/qt-6/qimagereader.html#textKeys

        **QStringList QImageReader::textKeys() const**

        Returns the text keys for this image. You can use these keys with
        **text** () to list the image text for a certain key.

        Support for this option is implemented through
        **QImageIOHandler::Description** .

        **See also** **text** (), **QImageWriter::setText** (), and
        **QImage::textKeys** ().
        """
        ...

    @staticmethod
    def supportedImageFormats() -> typing.List[QtCore.QByteArray]:
        """
        https://doc.qt.io/qt-6/qimagereader.html#supportedImageFormats

        **[static] QList<QByteArray> QImageReader::supportedImageFormats()**

        Returns the list of image formats supported by **QImageReader** .

        By default, Qt can read the following formats:

        FormatMIME typeDescription
        BMPimage/bmpWindows Bitmap
        GIFimage/gifGraphic Interchange Format (optional)
        JPGimage/jpegJoint
        Photographic Experts Group
        PNGimage/pngPortable Network Graphics
        PBMimage/x-portable-bitmapPortable Bitmap
        PGMimage/x-portable-
        graymapPortable Graymap
        PPMimage/x-portable-pixmapPortable Pixmap
        XBMimage/x-xbitmapX11 Bitmap
        XPMimage/x-xpixmapX11 Pixmap
        SVGimage/svg+xmlScalable Vector Graphics

        Reading and writing SVG files is supported through the **Qt SVG**
        module. The **Qt Image Formats**  module provides support for additional
        image formats.

        Note that the **QApplication**  instance must be created before this
        function is called.

        **See also** **setFormat** (), **QImageWriter::supportedImageFormats**
        (), and **QImageIOPlugin** .
        """
        ...

    @typing.overload
    @staticmethod
    def imageFormat(fileName: str) -> QtCore.QByteArray:
        """
        https://doc.qt.io/qt-6/qimagereader.html#imageFormat

        **QImage::Format QImageReader::imageFormat() const**

        Returns the format of the image, without actually reading the image
        contents. The format describes the image format **QImageReader::read**
        () returns, not the format of the actual image.

        If the image format does not support this feature, this function returns
        an invalid format.

        **See also** **QImageIOHandler::ImageOption** ,
        **QImageIOHandler::option** (), and **QImageIOHandler::supportsOption**
        ().
        """
        ...

    @typing.overload
    @staticmethod
    def imageFormat(device: QtCore.QIODevice) -> QtCore.QByteArray:
        """
        https://doc.qt.io/qt-6/qimagereader.html#imageFormat-1

        **[static] QByteArray QImageReader::imageFormat(const QString & fileName
        )**

        If supported, this function returns the image format of the file
        **fileName**. Otherwise, an empty string is returned.
        """
        ...

    @typing.overload
    def imageFormat(self) -> QImage.Format:
        """
        https://doc.qt.io/qt-6/qimagereader.html#imageFormat-2

        **[static] QByteArray QImageReader::imageFormat(QIODevice * device )**

        If supported, this function returns the image format of the device
        **device**. Otherwise, an empty string is returned.

        **See also** **QImageReader::autoDetectImageFormat** ().
        """
        ...

    def errorString(self) -> str:
        """
        https://doc.qt.io/qt-6/qimagereader.html#errorString

        **QString QImageReader::errorString() const**

        Returns a human readable description of the last error that occurred.

        **See also** **error** ().
        """
        ...

    def error(self) -> "QImageReader.ImageReaderError":
        """
        https://doc.qt.io/qt-6/qimagereader.html#error

        **QImageReader::ImageReaderError QImageReader::error() const**

        Returns the type of error that occurred last.

        **See also** **ImageReaderError**  and **errorString** ().
        """
        ...

    def currentImageRect(self) -> QtCore.QRect:
        """
        https://doc.qt.io/qt-6/qimagereader.html#currentImageRect

        **QRect QImageReader::currentImageRect() const**

        For image formats that support animation, this function returns the rect
        for the current frame. Otherwise, a null rect is returned.

        **See also** **supportsAnimation** () and
        **QImageIOHandler::currentImageRect** ().
        """
        ...

    def currentImageNumber(self) -> int:
        """
        https://doc.qt.io/qt-6/qimagereader.html#currentImageNumber

        **int QImageReader::currentImageNumber() const**

        For image formats that support animation, this function returns the
        sequence number of the current frame. If the image format doesn't
        support animation, 0 is returned.

        This function returns -1 if an error occurred.

        **See also** **supportsAnimation** (),
        **QImageIOHandler::currentImageNumber** (), and **canRead** ().
        """
        ...

    def nextImageDelay(self) -> int:
        """
        https://doc.qt.io/qt-6/qimagereader.html#nextImageDelay

        **int QImageReader::nextImageDelay() const**

        For image formats that support animation, this function returns the
        number of milliseconds to wait until displaying the next frame in the
        animation. If the image format doesn't support animation, 0 is returned.

        This function returns -1 if an error occurred.

        **See also** **supportsAnimation** (),
        **QImageIOHandler::nextImageDelay** (), and **canRead** ().
        """
        ...

    def imageCount(self) -> int:
        """
        https://doc.qt.io/qt-6/qimagereader.html#imageCount

        **int QImageReader::imageCount() const**

        For image formats that support animation, this function returns the
        total number of images in the animation. If the format does not support
        animation, 0 is returned.

        This function returns -1 if an error occurred.

        **See also** **supportsAnimation** (), **QImageIOHandler::imageCount**
        (), and **canRead** ().
        """
        ...

    def loopCount(self) -> int:
        """
        https://doc.qt.io/qt-6/qimagereader.html#loopCount

        **int QImageReader::loopCount() const**

        For image formats that support animation, this function returns the
        number of times the animation should loop. If this function returns -1,
        it can either mean the animation should loop forever, or that an error
        occurred. If an error occurred, **canRead** () will return false.

        **See also** **supportsAnimation** (), **QImageIOHandler::loopCount**
        (), and **canRead** ().
        """
        ...

    def jumpToImage(self, imageNumber: int) -> bool:
        """
        https://doc.qt.io/qt-6/qimagereader.html#jumpToImage

        **bool QImageReader::jumpToImage(int imageNumber )**

        For image formats that support animation, this function skips to the
        image whose sequence number is **imageNumber** , returning true if
        successful or false if the corresponding image cannot be found.

        The next call to **read** () will attempt to read this image.

        **See also** **jumpToNextImage** () and **QImageIOHandler::jumpToImage**
        ().
        """
        ...

    def jumpToNextImage(self) -> bool:
        """
        https://doc.qt.io/qt-6/qimagereader.html#jumpToNextImage

        **bool QImageReader::jumpToNextImage()**

        For image formats that support animation, this function steps over the
        current image, returning true if successful or false if there is no
        following image in the animation.

        The default implementation calls **read** (), then discards the
        resulting image, but the image handler may have a more efficient way of
        implementing this operation.

        **See also** **jumpToImage** () and **QImageIOHandler::jumpToNextImage**
        ().
        """
        ...

    @typing.overload
    def read(self) -> QImage:
        """
        https://doc.qt.io/qt-6/qimagereader.html#read

        **QImage QImageReader::read()**

        Reads an image from the device. On success, the image that was read is
        returned; otherwise, a null **QImage**  is returned. You can then call
        **error** () to find the type of error that occurred, or **errorString**
        () to get a human readable description of the error.

        For image formats that support animation, calling read() repeatedly will
        return the next frame. When all frames have been read, a null image will
        be returned.

        **See also** **canRead** (), **supportedImageFormats** (),
        **supportsAnimation** (), and **QMovie** .
        """
        ...

    @typing.overload
    def read(self, image: QImage) -> bool:
        """
        https://doc.qt.io/qt-6/qimagereader.html#read-1

        **bool QImageReader::read(QImage * image )**

        This is an overloaded function.

        Reads an image from the device into **image** , which must point to a
        **QImage** . Returns `true` on success; otherwise, returns `false`.

        If **image** has same format and size as the image data that is about to
        be read, this function may not need to allocate a new image before
        reading. Because of this, it can be faster than the other read()
        overload, which always constructs a new image; especially when reading
        several images with the same format and size.

        **QImage**  icon(64, 64, **QImage** ::Format_RGB32);
        **QImageReader**  reader("icon_64x64.bmp");
            if (reader.read(&icon))
        {
                // Display icon
            }

        For image formats that support animation, calling read() repeatedly will
        return the next frame. When all frames have been read, a null image will
        be returned.

        **See also** **canRead** (), **supportedImageFormats** (),
        **supportsAnimation** (), and **QMovie** .
        """
        ...

    def canRead(self) -> bool:
        """
        https://doc.qt.io/qt-6/qimagereader.html#canRead

        **bool QImageReader::canRead() const**

        Returns `true` if an image can be read for the device (i.e., the image
        format is supported, and the device seems to contain valid data);
        otherwise returns `false`.

        canRead() is a lightweight function that only does a quick test to see
        if the image data is valid. **read** () may still return false after
        canRead() returns `true`, if the image data is corrupt.

        **Note:** A **QMimeDatabase**  lookup is normally a better approach than
        this function for identifying potentially non-image files or data.

        For images that support animation, canRead() returns `false` when all
        frames have been read.

        **See also** **read** (), **supportedImageFormats** (), and
        **QMimeDatabase** .
        """
        ...

    def scaledClipRect(self) -> QtCore.QRect:
        """
        https://doc.qt.io/qt-6/qimagereader.html#scaledClipRect

        **QRect QImageReader::scaledClipRect() const**

        Returns the scaled clip rect of the image.

        **See also** **setScaledClipRect** ().
        """
        ...

    def setScaledClipRect(self, rect: QtCore.QRect) -> None:
        """
        https://doc.qt.io/qt-6/qimagereader.html#setScaledClipRect

        **void QImageReader::setScaledClipRect(const QRect & rect )**

        Sets the scaled clip rect to **rect**. The scaled clip rect is the clip
        rect (also known as ROI, or Region Of Interest) that is applied after
        the image has been scaled.

        **See also** **scaledClipRect** () and **setScaledSize** ().
        """
        ...

    def scaledSize(self) -> QtCore.QSize:
        """
        https://doc.qt.io/qt-6/qimagereader.html#scaledSize

        **QSize QImageReader::scaledSize() const**

        Returns the scaled size of the image.

        **See also** **setScaledSize** ().
        """
        ...

    def setScaledSize(self, size: QtCore.QSize) -> None:
        """
        https://doc.qt.io/qt-6/qimagereader.html#setScaledSize

        **void QImageReader::setScaledSize(const QSize & size )**

        Sets the scaled size of the image to **size**. The scaling is performed
        after the initial clip rect, but before the scaled clip rect is applied.
        The algorithm used for scaling depends on the image format. By default
        (i.e., if the image format does not support scaling), **QImageReader**
        will use QImage::scale() with Qt::SmoothScaling.

        **See also** **scaledSize** (), **setClipRect** (), and
        **setScaledClipRect** ().
        """
        ...

    def clipRect(self) -> QtCore.QRect:
        """
        https://doc.qt.io/qt-6/qimagereader.html#clipRect

        **QRect QImageReader::clipRect() const**

        Returns the clip rect (also known as the ROI, or Region Of Interest) of
        the image. If no clip rect has been set, an invalid **QRect**  is
        returned.

        **See also** **setClipRect** ().
        """
        ...

    def setClipRect(self, rect: QtCore.QRect) -> None:
        """
        https://doc.qt.io/qt-6/qimagereader.html#setClipRect

        **void QImageReader::setClipRect(const QRect & rect )**

        Sets the image clip rect (also known as the ROI, or Region Of Interest)
        to **rect**. The coordinates of **rect** are relative to the
        untransformed image size, as returned by **size** ().

        **See also** **clipRect** (), **setScaledSize** (), and
        **setScaledClipRect** ().
        """
        ...

    def size(self) -> QtCore.QSize:
        """
        https://doc.qt.io/qt-6/qimagereader.html#size

        **QSize QImageReader::size() const**

        Returns the size of the image, without actually reading the image
        contents.

        If the image format does not support this feature, this function returns
        an invalid size. Qt's built-in image handlers all support this feature,
        but custom image format plugins are not required to do so.

        **See also** **QImageIOHandler::ImageOption** ,
        **QImageIOHandler::option** (), and **QImageIOHandler::supportsOption**
        ().
        """
        ...

    def fileName(self) -> str:
        """
        https://doc.qt.io/qt-6/qimagereader.html#fileName

        **QString QImageReader::fileName() const**

        If the currently assigned device is a **QFile** , or if **setFileName**
        () has been called, this function returns the name of the file
        **QImageReader**  reads from. Otherwise (i.e., if no device has been
        assigned or the device is not a **QFile** ), an empty **QString**  is
        returned.

        **See also** **setFileName** () and **setDevice** ().
        """
        ...

    def setFileName(self, fileName: str) -> None:
        """
        https://doc.qt.io/qt-6/qimagereader.html#setFileName

        **void QImageReader::setFileName(const QString & fileName )**

        Sets the file name of **QImageReader**  to **fileName**. Internally,
        **QImageReader**  will create a **QFile**  object and open it in
        **ReadOnly**  mode, and use this when reading images.

        If **fileName** does not include a file extension (e.g., .png or .bmp),
        **QImageReader**  will cycle through all supported extensions until it
        finds a matching file.

        **See also** **fileName** (), **setDevice** (), and
        **supportedImageFormats** ().
        """
        ...

    def device(self) -> QtCore.QIODevice:
        """
        https://doc.qt.io/qt-6/qimagereader.html#device

        **QIODevice *QImageReader::device() const**

        Returns the device currently assigned to **QImageReader** , or `nullptr`
        if no device has been assigned.

        **See also** **setDevice** ().
        """
        ...

    def setDevice(self, device: QtCore.QIODevice) -> None:
        """
        https://doc.qt.io/qt-6/qimagereader.html#setDevice

        **void QImageReader::setDevice(QIODevice * device )**

        Sets **QImageReader** 's device to **device**. If a device has already
        been set, the old device is removed from **QImageReader**  and is
        otherwise left unchanged.

        If the device is not already open, **QImageReader**  will attempt to
        open the device in **ReadOnly**  mode by calling open(). Note that this
        does not work for certain devices, such as **QProcess** , **QTcpSocket**
        and **QUdpSocket** , where more logic is required to open the device.

        **See also** **device** () and **setFileName** ().
        """
        ...

    def format(self) -> QtCore.QByteArray:
        """
        https://doc.qt.io/qt-6/qimagereader.html#format

        **QByteArray QImageReader::format() const**

        Returns the format **QImageReader**  uses for reading images.

        You can call this function after assigning a device to the reader to
        determine the format of the device. For example:

        **QImageReader**  reader("image.png");
            // reader.format() == "png"

        If the reader cannot read any image from the device (e.g., there is no
        image there, or the image has already been read), or if the format is
        unsupported, this function returns an empty QByteArray().

        **See also** **setFormat** () and **supportedImageFormats** ().
        """
        ...

    def setFormat(self, format: QtCore.QByteArray) -> None:
        """
        https://doc.qt.io/qt-6/qimagereader.html#setFormat

        **void QImageReader::setFormat(const QByteArray & format )**

        Sets the format **QImageReader**  will use when reading images, to
        **format**. **format** is a case insensitive text string. Example:

        **QImageReader**  reader;
            reader.setFormat("png"); // same as
        reader.setFormat("PNG");

        You can call **supportedImageFormats** () for the full list of formats
        **QImageReader**  supports.

        **See also** **format** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip


class QMargins(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qmargins.html

    **Detailed Description**

    QMargin defines a set of four margins; left, top, right, and bottom, that
    describe the size of the borders surrounding a rectangle.

    The **isNull** () function returns `true` only if all margins are set to
    zero.

    QMargin objects can be streamed as well as compared.
    """

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qmargins.html#QMargins

        **QMargins::QMargins()**

        Constructs a margins object with all margins set to 0.

        **See also** **isNull** ().
        """
        ...

    @typing.overload
    def __init__(self, aleft: int, atop: int, aright: int, abottom: int) -> None:
        """
        https://doc.qt.io/qt-6/qmargins.html#QMargins-1

        **QMargins::QMargins(int left , int top , int right , int bottom )**

        Constructs margins with the given **left** , **top** , **right** , and
        **bottom**

        **See also** **setLeft** (), **setRight** (), **setTop** (), and
        **setBottom** ().
        """
        ...

    @typing.overload
    def __init__(self, a0: "QMargins") -> None:
        """
        https://doc.qt.io/qt-6/qmargins.html#QMargins

        **QMargins::QMargins()**

        Constructs a margins object with all margins set to 0.

        **See also** **isNull** ().
        """
        ...

    def __pos__(self) -> "QMargins":
        ...

    def __neg__(self) -> "QMargins":
        ...

    def setBottom(self, abottom: int) -> None:
        """
        https://doc.qt.io/qt-6/qmargins.html#setBottom

        **void QMargins::setBottom(int bottom )**

        Sets the bottom margin to **bottom**.

        **See also** **bottom** ().
        """
        ...

    def setRight(self, aright: int) -> None:
        """
        https://doc.qt.io/qt-6/qmargins.html#setRight

        **void QMargins::setRight(int right )**

        Sets the right margin to **right**.

        **See also** **right** ().
        """
        ...

    def setTop(self, atop: int) -> None:
        """
        https://doc.qt.io/qt-6/qmargins.html#setTop

        **void QMargins::setTop(int Top )**

        Sets the Top margin to **Top**.

        **See also** **top** ().
        """
        ...

    def setLeft(self, aleft: int) -> None:
        """
        https://doc.qt.io/qt-6/qmargins.html#setLeft

        **void QMargins::setLeft(int left )**

        Sets the left margin to **left**.

        **See also** **left** ().
        """
        ...

    def bottom(self) -> int:
        """
        https://doc.qt.io/qt-6/qmargins.html#bottom

        **int QMargins::bottom() const**

        Returns the bottom margin.

        **See also** **setBottom** ().
        """
        ...

    def right(self) -> int:
        """
        https://doc.qt.io/qt-6/qmargins.html#right

        **int QMargins::right() const**

        Returns the right margin.

        **See also** **setRight** ().
        """
        ...

    def top(self) -> int:
        """
        https://doc.qt.io/qt-6/qmargins.html#top

        **int QMargins::top() const**

        Returns the top margin.

        **See also** **setTop** ().
        """
        ...

    def left(self) -> int:
        """
        https://doc.qt.io/qt-6/qmargins.html#left

        **int QMargins::left() const**

        Returns the left margin.

        **See also** **setLeft** ().
        """
        ...

    def isNull(self) -> bool:
        """
        https://doc.qt.io/qt-6/qmargins.html#isNull

        **bool QMargins::isNull() const**

        Returns `true` if all margins are is 0; otherwise returns false.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip


class QDnsDomainNameRecord(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qdnsdomainnamerecord.html

    **Detailed Description**

    When performing a name server lookup, zero or more records will be returned.
    Each record is represented by a QDnsDomainNameRecord instance.

    **See also** **QDnsLookup** .
    """

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qdnsdomainnamerecord.html#QDnsDomainNameRecord

        **QDnsDomainNameRecord::QDnsDomainNameRecord()**

        Constructs an empty domain name record object.
        """
        ...

    @typing.overload
    def __init__(self, other: "QDnsDomainNameRecord") -> None:
        """
        https://doc.qt.io/qt-6/qdnsdomainnamerecord.html#QDnsDomainNameRecord-1

        **QDnsDomainNameRecord::QDnsDomainNameRecord(const QDnsDomainNameRecord
        & other )**

        Constructs a copy of **other**.
        """
        ...

    def value(self) -> str:
        """
        https://doc.qt.io/qt-6/qdnsdomainnamerecord.html#value

        **QString QDnsDomainNameRecord::value() const**

        Returns the value for this domain name record.
        """
        ...

    def timeToLive(self) -> int:
        """
        https://doc.qt.io/qt-6/qdnsdomainnamerecord.html#timeToLive

        **quint32 QDnsDomainNameRecord::timeToLive() const**

        Returns the duration in seconds for which this record is valid.
        """
        ...

    def name(self) -> str:
        """
        https://doc.qt.io/qt-6/qdnsdomainnamerecord.html#name

        **QString QDnsDomainNameRecord::name() const**

        Returns the name for this record.
        """
        ...

    def swap(self, other: "QDnsDomainNameRecord") -> None:
        """
        https://doc.qt.io/qt-6/qdnsdomainnamerecord.html#swap

        **void QDnsDomainNameRecord::swap(QDnsDomainNameRecord & other )**

        Swaps this domain-name record instance with **other**. This function is
        very fast and never fails.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip
from PyQt6.QtCore import *


class QItemSelectionRange(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qitemselectionrange.html

    **Detailed Description**

    A QItemSelectionRange contains information about a range of selected items
    in a model. A range of items is a contiguous array of model items, extending
    to cover a number of adjacent rows and columns with a common parent item;
    this can be visualized as a two-dimensional block of cells in a table. A
    selection range has a **top** (), **left** () a **bottom** (), **right** ()
    and a **parent** ().

    The QItemSelectionRange class is one of the **Model/View Classes**  and is
    part of Qt's **model/view framework** .

    The model items contained in the selection range can be obtained using the
    **indexes** () function. Use **QItemSelectionModel::selectedIndexes** () to
    get a list of all selected items for a view.

    You can determine whether a given model item lies within a particular range
    by using the **contains** () function. Ranges can also be compared using the
    overloaded operators for equality and inequality, and the **intersects** ()
    function allows you to determine whether two ranges overlap.

    **See also** **Model/View Programming** , **QAbstractItemModel** ,
    **QItemSelection** , and **QItemSelectionModel** .
    """

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qitemselectionrange.html#QItemSelectionRange

        **QItemSelectionRange::QItemSelectionRange()**

        Constructs an empty selection range.
        """
        ...

    @typing.overload
    def __init__(self, atopLeft: QModelIndex, abottomRight: QModelIndex) -> None:
        """
        https://doc.qt.io/qt-6/qitemselectionrange.html#QItemSelectionRange-1

        **QItemSelectionRange::QItemSelectionRange(const QModelIndex & topLeft ,
        const QModelIndex & bottomRight )**

        Constructs a new selection range containing only the index specified by
        the **topLeft** and the index **bottomRight**.
        """
        ...

    @typing.overload
    def __init__(self, index: QModelIndex) -> None:
        """
        https://doc.qt.io/qt-6/qitemselectionrange.html#QItemSelectionRange-2

        **QItemSelectionRange::QItemSelectionRange(const QModelIndex & index )**

        Constructs a new selection range containing only the model item
        specified by the model index **index**.
        """
        ...

    @typing.overload
    def __init__(self, a0: "QItemSelectionRange") -> None:
        """
        https://doc.qt.io/qt-6/qitemselectionrange.html#QItemSelectionRange

        **QItemSelectionRange::QItemSelectionRange()**

        Constructs an empty selection range.
        """
        ...

    def swap(self, other: "QItemSelectionRange") -> None:
        """
        https://doc.qt.io/qt-6/qitemselectionrange.html#swap

        **[since 5.6] void QItemSelectionRange::swap(QItemSelectionRange & other
        )**

        Swaps this selection range's contents with **other**. This function is
        very fast and never fails.

        This function was introduced in Qt 5.6.
        """
        ...

    def isEmpty(self) -> bool:
        """
        https://doc.qt.io/qt-6/qitemselectionrange.html#isEmpty

        **bool QItemSelectionRange::isEmpty() const**

        Returns `true` if the selection range contains either no items or only
        items which are either disabled or marked as not selectable.
        """
        ...

    def intersected(self, other: "QItemSelectionRange") -> "QItemSelectionRange":
        """
        https://doc.qt.io/qt-6/qitemselectionrange.html#intersected

        **QItemSelectionRange QItemSelectionRange::intersected(const
        QItemSelectionRange & other ) const**

        Returns a new selection range containing only the items that are found
        in both the selection range and the **other** selection range.
        """
        ...

    def indexes(self) -> typing.List[QModelIndex]:
        """
        https://doc.qt.io/qt-6/qitemselectionrange.html#indexes

        **QModelIndexList QItemSelectionRange::indexes() const**

        Returns the list of model index items stored in the selection.
        """
        ...

    def isValid(self) -> bool:
        """
        https://doc.qt.io/qt-6/qitemselectionrange.html#isValid

        **bool QItemSelectionRange::isValid() const**

        Returns `true` if the selection range is valid; otherwise returns
        `false`.
        """
        ...

    def intersects(self, other: "QItemSelectionRange") -> bool:
        """
        https://doc.qt.io/qt-6/qitemselectionrange.html#intersects

        **bool QItemSelectionRange::intersects(const QItemSelectionRange & other
        ) const**

        Returns `true` if this selection range intersects (overlaps with) the
        **other** range given; otherwise returns `false`.
        """
        ...

    @typing.overload
    def contains(self, index: QModelIndex) -> bool:
        """
        https://doc.qt.io/qt-6/qitemselectionrange.html#contains

        **bool QItemSelectionRange::contains(const QModelIndex & index ) const**

        Returns `true` if the model item specified by the **index** lies within
        the range of selected items; otherwise returns `false`.
        """
        ...

    @typing.overload
    def contains(self, row: int, column: int, parentIndex: QModelIndex) -> bool:
        """
        https://doc.qt.io/qt-6/qitemselectionrange.html#contains-1

        **bool QItemSelectionRange::contains(int row , int column , const
        QModelIndex & parentIndex ) const**

        This is an overloaded function.

        Returns `true` if the model item specified by ( **row** , **column** )
        and with **parentIndex** as the parent item lies within the range of
        selected items; otherwise returns `false`.
        """
        ...

    def model(self) -> QAbstractItemModel:
        """
        https://doc.qt.io/qt-6/qitemselectionrange.html#model

        **const QAbstractItemModel *QItemSelectionRange::model() const**

        Returns the model that the items in the selection range belong to.
        """
        ...

    def parent(self) -> QModelIndex:
        """
        https://doc.qt.io/qt-6/qitemselectionrange.html#parent

        **QModelIndex QItemSelectionRange::parent() const**

        Returns the parent model item index of the items in the selection range.
        """
        ...

    def bottomRight(self) -> QPersistentModelIndex:
        """
        https://doc.qt.io/qt-6/qitemselectionrange.html#bottomRight

        **const QPersistentModelIndex &QItemSelectionRange::bottomRight()
        const**

        Returns the index for the item located at the bottom-right corner of the
        selection range.

        **See also** **bottom** (), **right** (), and **topLeft** ().
        """
        ...

    def topLeft(self) -> QPersistentModelIndex:
        """
        https://doc.qt.io/qt-6/qitemselectionrange.html#topLeft

        **const QPersistentModelIndex &QItemSelectionRange::topLeft() const**

        Returns the index for the item located at the top-left corner of the
        selection range.

        **See also** **top** (), **left** (), and **bottomRight** ().
        """
        ...

    def height(self) -> int:
        """
        https://doc.qt.io/qt-6/qitemselectionrange.html#height

        **int QItemSelectionRange::height() const**

        Returns the number of selected rows in the selection range.
        """
        ...

    def width(self) -> int:
        """
        https://doc.qt.io/qt-6/qitemselectionrange.html#width

        **int QItemSelectionRange::width() const**

        Returns the number of selected columns in the selection range.
        """
        ...

    def right(self) -> int:
        """
        https://doc.qt.io/qt-6/qitemselectionrange.html#right

        **int QItemSelectionRange::right() const**

        Returns the column index corresponding to the rightmost selected column
        in the selection range.
        """
        ...

    def bottom(self) -> int:
        """
        https://doc.qt.io/qt-6/qitemselectionrange.html#bottom

        **int QItemSelectionRange::bottom() const**

        Returns the row index corresponding to the lowermost selected row in the
        selection range.
        """
        ...

    def left(self) -> int:
        """
        https://doc.qt.io/qt-6/qitemselectionrange.html#left

        **int QItemSelectionRange::left() const**

        Returns the column index corresponding to the leftmost selected column
        in the selection range.
        """
        ...

    def top(self) -> int:
        """
        https://doc.qt.io/qt-6/qitemselectionrange.html#top

        **int QItemSelectionRange::top() const**

        Returns the row index corresponding to the uppermost selected row in the
        selection range.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip
from PyQt6 import QtWidgets
from PyQt6 import QtCore
from PyQt6.QtPrintSupport import *


class QPrintPreviewDialog(QtWidgets.QDialog):
    """
    https://doc.qt.io/qt-6/qprintpreviewdialog.html

    **Detailed Description**

    Using QPrintPreviewDialog in your existing application is straightforward:

    1. Create the QPrintPreviewDialog.

    You can construct a QPrintPreviewDialog
    with an existing **QPrinter**  object, or you can have QPrintPreviewDialog
    create one for you, which will be the system default printer.

      2. Connect
    the **paintRequested** () signal to a slot.

    When the dialog needs to
    generate a set of preview pages, the **paintRequested** () signal will be
    emitted. You can use the exact same code for the actual printing as for
    having the preview generated, including calling **QPrinter::newPage** () to
    start a new page in the preview. Connect a slot to the **paintRequested** ()
    signal, where you draw onto the **QPrinter**  object that is passed into the
    slot.

      3. Call **exec** ().

    Call **QPrintPreviewDialog::exec** () to show
    the preview dialog.

    **See also** **QPrinter** , **QPrintDialog** , **QPageSetupDialog** , and
    **QPrintPreviewWidget** .
    """

    @typing.overload
    def __init__(
        self,
        parent: typing.Optional[QtWidgets.QWidget] = ...,
        flags: QtCore.Qt.WindowType = ...,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qprintpreviewdialog.html#QPrintPreviewDialog

        **QPrintPreviewDialog::QPrintPreviewDialog(QPrinter * printer , QWidget
        * parent = nullptr, Qt::WindowFlags flags = Qt::WindowFlags())**

        Constructs a QPrintPreviewDialog based on **printer** and with
        **parent** as the parent widget. The widget flags **flags** are passed
        on to the **QWidget**  constructor.

        **See also** **QWidget::setWindowFlags** ().
        """
        ...

    @typing.overload
    def __init__(
        self,
        printer: QPrinter,
        parent: typing.Optional[QtWidgets.QWidget] = ...,
        flags: QtCore.Qt.WindowType = ...,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qprintpreviewdialog.html#QPrintPreviewDialog-1

        **QPrintPreviewDialog::QPrintPreviewDialog(QWidget * parent = nullptr,
        Qt::WindowFlags flags = Qt::WindowFlags())**

        This is an overloaded function.

        This will create an internal **QPrinter**  object, which will use the
        system default printer.
        """
        ...

    def done(self, result: int) -> None:
        """
        https://doc.qt.io/qt-6/qprintpreviewdialog.html#done

        **[override virtual] void QPrintPreviewDialog::done(int result )**

        Reimplements: **QDialog::done** (int r).
        """
        ...

    def printer(self) -> QPrinter:
        """
        https://doc.qt.io/qt-6/qprintpreviewdialog.html#printer

        **QPrinter *QPrintPreviewDialog::printer()**

        Returns a pointer to the **QPrinter**  object this dialog is currently
        operating on.
        """
        ...

    @typing.overload
    def open(self) -> None:
        """
        https://doc.qt.io/qt-6/qprintpreviewdialog.html#open

        **void QPrintPreviewDialog::open(QObject * receiver , const char *
        member )**

        This is an overloaded function.

        Opens the dialog and connects its finished(int) signal to the slot
        specified by **receiver** and **member**.

        The signal will be disconnected from the slot when the dialog is closed.
        """
        ...

    @typing.overload
    def open(self, slot: PYQT_SLOT) -> None:
        """
        https://doc.qt.io/qt-6/qprintpreviewdialog.html#open

        **void QPrintPreviewDialog::open(QObject * receiver , const char *
        member )**

        This is an overloaded function.

        Opens the dialog and connects its finished(int) signal to the slot
        specified by **receiver** and **member**.

        The signal will be disconnected from the slot when the dialog is closed.
        """
        ...

    def setVisible(self, visible: bool) -> None:
        """
        https://doc.qt.io/qt-6/qprintpreviewdialog.html#setVisible

        **[override virtual] void QPrintPreviewDialog::setVisible(bool visible
        )**

        Reimplements: **QDialog::setVisible** (bool visible).
        """
        ...

    @property
    def paintRequested(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qprintpreviewdialog.html#paintRequested

        **[signal] void QPrintPreviewDialog::paintRequested(QPrinter * printer
        )**

        This signal is emitted when the **QPrintPreviewDialog**  needs to
        generate a set of preview pages.

        The **printer** instance supplied is the paint device onto which you
        should paint the contents of each page, using the **QPrinter**  instance
        in the same way as you would when printing directly.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip
from PyQt6.QtCore import *


class QTimer(QObject):
    """
    https://doc.qt.io/qt-6/qtimer.html

    **Detailed Description**

    The QTimer class provides a high-level programming interface for timers. To
    use it, create a QTimer, connect its **timeout** () signal to the
    appropriate slots, and call **start** (). From then on, it will emit the
    **timeout** () signal at constant intervals.

    Example for a one second (1000 millisecond) timer (from the **Analog Clock**
    example):

    **QTimer**  *timer = new **QTimer** (this);
            connect(timer,
    &**QTimer** ::timeout, this, QOverload<>::of(&AnalogClock::update));
    timer->start(1000);

    From then on, the `update()` slot is called every second.

    You can set a timer to time out only once by calling **setSingleShot**
    (true). You can also use the static **QTimer::singleShot** () function to
    call a slot after a specified interval:

    **QTimer** ::singleShot(200, this, &Foo::updateCaption);

    In multithreaded applications, you can use QTimer in any thread that has an
    event loop. To start an event loop from a non-GUI thread, use
    **QThread::exec** (). Qt uses the timer's **thread affinity**  to determine
    which thread will emit the **timeout** () signal. Because of this, you must
    start and stop the timer in its thread; it is not possible to start a timer
    from another thread.

    As a special case, a QTimer with a timeout of 0 will time out as soon as
    possible, though the ordering between zero timers and other sources of
    events is unspecified. Zero timers can be used to do some work while still
    providing a snappy user interface:

    **QTimer**  *timer = new **QTimer** (this);
            connect(timer,
    &**QTimer** ::timeout, this, &Foo::processOneThing);
            timer->start();

    From then on, `processOneThing()` will be called repeatedly. It should be
    written in such a way that it always returns quickly (typically after
    processing one data item) so that Qt can deliver events to the user
    interface and stop the timer as soon as it has done all its work. This is
    the traditional way of implementing heavy work in GUI applications, but as
    multithreading is nowadays becoming available on more and more platforms, we
    expect that zero-millisecond QTimer objects will gradually be replaced by
    **QThread** s.

    **Accuracy and Timer Resolution**

    The accuracy of timers depends on the underlying operating system and
    hardware. Most platforms support a resolution of 1 millisecond, though the
    accuracy of the timer will not equal this resolution in many real-world
    situations.

    The accuracy also depends on the **timer type** . For **Qt::PreciseTimer** ,
    QTimer will try to keep the accuracy at 1 millisecond. Precise timers will
    also never time out earlier than expected.

    For **Qt::CoarseTimer**  and **Qt::VeryCoarseTimer**  types, QTimer may wake
    up earlier than expected, within the margins for those types: 5% of the
    interval for **Qt::CoarseTimer**  and 500 ms for **Qt::VeryCoarseTimer** .

    All timer types may time out later than expected if the system is busy or
    unable to provide the requested accuracy. In such a case of timeout overrun,
    Qt will emit **timeout** () only once, even if multiple timeouts have
    expired, and then will resume the original interval.

    **Alternatives to QTimer**

    An alternative to using QTimer is to call **QObject::startTimer** () for
    your object and reimplement the **QObject::timerEvent** () event handler in
    your class (which must inherit **QObject** ). The disadvantage is that
    **timerEvent** () does not support such high-level features as single-shot
    timers or signals.

    Another alternative is **QBasicTimer** . It is typically less cumbersome
    than using **QObject::startTimer** () directly. See **Timers**  for an
    overview of all three approaches.

    Some operating systems limit the number of timers that may be used; Qt tries
    to work around these limitations.

    **See also** **QBasicTimer** , **QTimerEvent** , **QObject::timerEvent** (),
    **Timers** , **Analog Clock Example** , and **Wiggly Example** .
    """

    def __init__(self, parent: typing.Optional[QObject] = ...) -> None:
        """
        https://doc.qt.io/qt-6/qtimer.html#QTimer

        **QTimer::QTimer(QObject * parent = nullptr)**

        Constructs a timer with the given **parent**.
        """
        ...

    def remainingTime(self) -> int:
        """
        https://doc.qt.io/qt-6/qtimer.html#remainingTime-prop

        **[read-only, since 5.0] remainingTime : const int**

        This property holds the remaining time in milliseconds

        Returns the timer's remaining value in milliseconds left until the
        timeout. If the timer is inactive, the returned value will be -1. If the
        timer is overdue, the returned value will be 0.

        This property was introduced in Qt 5.0.

        **Access functions:**

        int **remainingTime** () const

        **See also** **interval** .
        """
        ...

    def timerType(self) -> Qt.TimerType:
        """
        https://doc.qt.io/qt-6/qtimer.html#timerType-prop

        **[bindable] timerType : Qt::TimerType**

        **Note:** This property supports **QProperty**  bindings.

        controls the accuracy of the timer

        The default value for this property is `Qt::CoarseTimer`.

        **See also** **Qt::TimerType** .

        **Member Function Documentation**
        """
        ...

    def setTimerType(self, atype: Qt.TimerType) -> None:
        """
        https://doc.qt.io/qt-6/qtimer.html#timerType-prop

        **[bindable] timerType : Qt::TimerType**

        **Note:** This property supports **QProperty**  bindings.

        controls the accuracy of the timer

        The default value for this property is `Qt::CoarseTimer`.

        **See also** **Qt::TimerType** .

        **Member Function Documentation**
        """
        ...

    def timerEvent(self, a0: QTimerEvent) -> None:
        """
        https://doc.qt.io/qt-6/qtimer.html#timerEvent

        **[override virtual protected] void QTimer::timerEvent(QTimerEvent * e
        )**

        Reimplements: **QObject::timerEvent** (QTimerEvent *event).
        """
        ...

    def stop(self) -> None:
        """
        https://doc.qt.io/qt-6/qtimer.html#stop

        **[slot] void QTimer::stop()**

        Stops the timer.

        **See also** **start** ().
        """
        ...

    @typing.overload
    def start(self, msec: int) -> None:
        """
        https://doc.qt.io/qt-6/qtimer.html#start

        **[slot] void QTimer::start(int msec )**

        Starts or restarts the timer with a timeout interval of **msec**
        milliseconds.

        If the timer is already running, it will be **stopped**  and restarted.

        If **singleShot**  is true, the timer will be activated only once.
        """
        ...

    @typing.overload
    def start(self) -> None:
        """
        https://doc.qt.io/qt-6/qtimer.html#start-1

        **[slot] void QTimer::start()**

        This function overloads start().

        Starts or restarts the timer with the timeout specified in **interval**
        .

        If the timer is already running, it will be **stopped**  and restarted.

        If **singleShot**  is true, the timer will be activated only once.
        """
        ...

    @typing.overload
    @staticmethod
    def singleShot(msec: int, slot: PYQT_SLOT) -> None:
        """
        https://doc.qt.io/qt-6/qtimer.html#singleShot

        **[static] void QTimer::singleShot(int msec , const QObject * receiver ,
        const char * member )**

        This static function calls a slot after a given time interval.

        It is very convenient to use this function because you do not need to
        bother with a **timerEvent**  or create a local **QTimer**  object.

        Example:

        #include <QApplication>
            #include <QTimer>

            int main(int
        argc, char *argv[])
            {
                **QApplication**  app(argc, argv);
        **QTimer** ::singleShot(600000, &app, SLOT(quit()));
                ...
        return app.exec();
            }

        This sample program automatically terminates after 10 minutes (600,000
        milliseconds).

        The **receiver** is the receiving object and the **member** is the slot.
        The time interval is **msec** milliseconds.

        **Note:** This function is **reentrant** .

        **See also** **setSingleShot** () and **start** ().
        """
        ...

    @typing.overload
    @staticmethod
    def singleShot(msec: int, timerType: Qt.TimerType, slot: PYQT_SLOT) -> None:
        """
        https://doc.qt.io/qt-6/qtimer.html#singleShot-prop

        **[bindable] singleShot : bool**

        **Note:** This property supports **QProperty**  bindings.

        This property holds whether the timer is a single-shot timer

        A single-shot timer fires only once, non-single-shot timers fire every
        **interval**  milliseconds.

        The default value for this property is `false`.

        **See also** **interval**  and **singleShot** ().
        """
        ...

    def setSingleShot(self, asingleShot: bool) -> None:
        """
        https://doc.qt.io/qt-6/qtimer.html#singleShot-1

        **[static] void QTimer::singleShot(int msec , Qt::TimerType timerType ,
        const QObject * receiver , const char * member )**

        This is an overloaded function.

        This static function calls a slot after a given time interval.

        It is very convenient to use this function because you do not need to
        bother with a **timerEvent**  or create a local **QTimer**  object.

        The **receiver** is the receiving object and the **member** is the slot.
        The time interval is **msec** milliseconds. The **timerType** affects
        the accuracy of the timer.

        **Note:** This function is **reentrant** .

        **See also** **start** ().
        """
        ...

    def isSingleShot(self) -> bool:
        ...

    def interval(self) -> int:
        """
        https://doc.qt.io/qt-6/qtimer.html#interval-prop

        **[bindable] interval : int**

        **Note:** This property supports **QProperty**  bindings.

        This property holds the timeout interval in milliseconds

        The default value for this property is 0. A **QTimer**  with a timeout
        interval of 0 will time out as soon as all the events in the window
        system's event queue have been processed.

        Setting the interval of an active timer changes its **timerId** ().

        **See also** **singleShot** .
        """
        ...

    def setInterval(self, msec: int) -> None:
        """
        https://doc.qt.io/qt-6/qtimer.html#interval-prop

        **[bindable] interval : int**

        **Note:** This property supports **QProperty**  bindings.

        This property holds the timeout interval in milliseconds

        The default value for this property is 0. A **QTimer**  with a timeout
        interval of 0 will time out as soon as all the events in the window
        system's event queue have been processed.

        Setting the interval of an active timer changes its **timerId** ().

        **See also** **singleShot** .
        """
        ...

    def timerId(self) -> int:
        """
        https://doc.qt.io/qt-6/qtimer.html#timerId

        **int QTimer::timerId() const**

        Returns the ID of the timer if the timer is running; otherwise returns
        -1.
        """
        ...

    def isActive(self) -> bool:
        """
        https://doc.qt.io/qt-6/qtimer.html#isActive

        **bool QTimer::isActive() const**

        Returns `true` if the timer is running (pending); otherwise returns
        false.

        **Note:** Getter function for property **active** .
        """
        ...

    @property
    def timeout(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qtimer.html#timeout

        **[private signal] void QTimer::timeout()**

        This signal is emitted when the timer times out.

        **Note:** This is a private signal. It can be used in signal connections
        but cannot be emitted by the user.

        **See also** **interval** , **start** (), and **stop** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip
from PyQt6.QtXml import *


class QDomNamedNodeMap(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qdomnamednodemap.html

    **Detailed Description**

    Note that QDomNamedNodeMap does not inherit from **QDomNodeList** .
    QDomNamedNodeMaps do not provide any specific node ordering. Although nodes
    in a QDomNamedNodeMap may be accessed by an ordinal index, this is simply to
    allow a convenient enumeration of the contents of a QDomNamedNodeMap, and
    does not imply that the DOM specifies an ordering of the nodes.

    The QDomNamedNodeMap is used in three places:

    1. **QDomDocumentType::entities** () returns a map of all entities described
    in the DTD.
      2. **QDomDocumentType::notations** () returns a map of all
    notations described in the DTD.
      3. **QDomNode::attributes** () returns a
    map of all attributes of an element.

    Items in the map are identified by the name which QDomNode::name() returns.
    Nodes are retrieved using **namedItem** (), **namedItemNS** () or **item**
    (). New nodes are inserted with **setNamedItem** () or **setNamedItemNS** ()
    and removed with **removeNamedItem** () or **removeNamedItemNS** (). Use
    **contains** () to see if an item with the given name is in the named node
    map. The number of items is returned by **length** ().

    Terminology: in this class we use "item" and "node" interchangeably.
    """

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qdomnamednodemap.html#QDomNamedNodeMap

        **QDomNamedNodeMap::QDomNamedNodeMap()**

        Constructs an empty named node map.
        """
        ...

    @typing.overload
    def __init__(self, a0: "QDomNamedNodeMap") -> None:
        """
        https://doc.qt.io/qt-6/qdomnamednodemap.html#QDomNamedNodeMap-1

        **QDomNamedNodeMap::QDomNamedNodeMap(const QDomNamedNodeMap & n )**

        Constructs a copy of **n**.
        """
        ...

    def contains(self, name: str) -> bool:
        """
        https://doc.qt.io/qt-6/qdomnamednodemap.html#contains

        **bool QDomNamedNodeMap::contains(const QString & name ) const**

        Returns `true` if the map contains a node called **name** ; otherwise
        returns `false`.

        **Note:** This function does not take the presence of namespaces into
        account. Use **namedItemNS** () to test whether the map contains a node
        with a specific namespace URI and name.
        """
        ...

    def isEmpty(self) -> bool:
        """
        https://doc.qt.io/qt-6/qdomnamednodemap.html#isEmpty

        **bool QDomNamedNodeMap::isEmpty() const**

        Returns `true` if the map is empty; otherwise returns `false`. This
        function is provided for Qt API consistency.
        """
        ...

    def size(self) -> int:
        """
        https://doc.qt.io/qt-6/qdomnamednodemap.html#size

        **int QDomNamedNodeMap::size() const**

        This function is provided for Qt API consistency. It is equivalent to
        **length** ().
        """
        ...

    def __len__(self) -> int:
        ...

    def count(self) -> int:
        """
        https://doc.qt.io/qt-6/qdomnamednodemap.html#count

        **int QDomNamedNodeMap::count() const**

        This function is provided for Qt API consistency. It is equivalent to
        **length** ().
        """
        ...

    def length(self) -> int:
        """
        https://doc.qt.io/qt-6/qdomnamednodemap.html#length

        **int QDomNamedNodeMap::length() const**

        Returns the number of nodes in the map.

        **See also** **item** ().
        """
        ...

    def removeNamedItemNS(self, nsURI: str, localName: str) -> QDomNode:
        """
        https://doc.qt.io/qt-6/qdomnamednodemap.html#removeNamedItemNS

        **QDomNode QDomNamedNodeMap::removeNamedItemNS(const QString & nsURI ,
        const QString & localName )**

        Removes the node with the local name **localName** and the namespace URI
        **nsURI** from the map.

        The function returns the removed node or a **null node**  if the map did
        not contain a node with the local name **localName** and the namespace
        URI **nsURI**.

        **See also** **setNamedItemNS** (), **namedItemNS** (), and
        **removeNamedItem** ().
        """
        ...

    def setNamedItemNS(self, newNode: QDomNode) -> QDomNode:
        """
        https://doc.qt.io/qt-6/qdomnamednodemap.html#setNamedItemNS

        **QDomNode QDomNamedNodeMap::setNamedItemNS(const QDomNode & newNode )**

        Inserts the node **newNode** in the map. If a node with the same
        namespace URI and the same local name already exists in the map, it is
        replaced by **newNode**. If the new node replaces an existing node, the
        replaced node is returned.

        **See also** **namedItemNS** (), **removeNamedItemNS** (), and
        **setNamedItem** ().
        """
        ...

    def namedItemNS(self, nsURI: str, localName: str) -> QDomNode:
        """
        https://doc.qt.io/qt-6/qdomnamednodemap.html#namedItemNS

        **QDomNode QDomNamedNodeMap::namedItemNS(const QString & nsURI , const
        QString & localName ) const**

        Returns the node associated with the local name **localName** and the
        namespace URI **nsURI**.

        If the map does not contain such a node, a **null node**  is returned.

        **See also** **setNamedItemNS** () and **namedItem** ().
        """
        ...

    def item(self, index: int) -> QDomNode:
        """
        https://doc.qt.io/qt-6/qdomnamednodemap.html#item

        **QDomNode QDomNamedNodeMap::item(int index ) const**

        Retrieves the node at position **index**.

        This can be used to iterate over the map. Note that the nodes in the map
        are ordered arbitrarily.

        **See also** **length** ().
        """
        ...

    def removeNamedItem(self, name: str) -> QDomNode:
        """
        https://doc.qt.io/qt-6/qdomnamednodemap.html#removeNamedItem

        **QDomNode QDomNamedNodeMap::removeNamedItem(const QString & name )**

        Removes the node called **name** from the map.

        The function returns the removed node or a **null node**  if the map did
        not contain a node called **name**.

        **See also** **setNamedItem** (), **namedItem** (), and
        **removeNamedItemNS** ().
        """
        ...

    def setNamedItem(self, newNode: QDomNode) -> QDomNode:
        """
        https://doc.qt.io/qt-6/qdomnamednodemap.html#setNamedItem

        **QDomNode QDomNamedNodeMap::setNamedItem(const QDomNode & newNode )**

        Inserts the node **newNode** into the named node map. The name used by
        the map is the node name of **newNode** as returned by
        **QDomNode::nodeName** ().

        If the new node replaces an existing node, i.e. the map contains a node
        with the same name, the replaced node is returned.

        **See also** **namedItem** (), **removeNamedItem** (), and
        **setNamedItemNS** ().
        """
        ...

    def namedItem(self, name: str) -> QDomNode:
        """
        https://doc.qt.io/qt-6/qdomnamednodemap.html#namedItem

        **QDomNode QDomNamedNodeMap::namedItem(const QString & name ) const**

        Returns the node called **name**.

        If the named node map does not contain such a node, a **null node**  is
        returned. A node's name is the name returned by **QDomNode::nodeName**
        ().

        **See also** **setNamedItem** () and **namedItemNS** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
import PyQt6.sip
from PyQt6 import QtCore
from PyQt6.QtBluetooth import *
import enum


class QBluetoothDeviceDiscoveryAgent(QtCore.QObject):
    """
    https://doc.qt.io/qt-6/qbluetoothdevicediscoveryagent.html

    **Detailed Description**

    To discover the nearby Bluetooth devices:

    * create an instance of QBluetoothDeviceDiscoveryAgent,
      * connect to
    either the **deviceDiscovered** () or **finished** () signals,
      * and call
    **start** ().

    void MyClass::startDeviceDiscovery()
        {

            // Create a
    discovery agent and connect to its signals
    **QBluetoothDeviceDiscoveryAgent**  *discoveryAgent = new
    **QBluetoothDeviceDiscoveryAgent** (this);
            connect(discoveryAgent,
    SIGNAL(deviceDiscovered(**QBluetoothDeviceInfo** )),
                    this,
    SLOT(deviceDiscovered(**QBluetoothDeviceInfo** )));

            // Start a
    discovery
            discoveryAgent->start();

            //...
        }
    // In your local slot, read information about the found devices
        void
    MyClass::deviceDiscovered(const **QBluetoothDeviceInfo**  &device)
        {
    **qDebug** () << "Found new device:" << device.name() << '(' <<
    device.address().toString() << ')';
        }

    To retrieve results asynchronously, connect to the **deviceDiscovered** ()
    signal. To get a list of all discovered devices, call **discoveredDevices**
    () after the **finished** () signal.

    This class can be used to discover Classic and Low Energy Bluetooth devices.
    The individual device type can be determined via the
    **QBluetoothDeviceInfo::coreConfigurations** () attribute. In most cases the
    list returned by **discoveredDevices** () contains both types of devices.
    However not every platform can detect both types of devices. On platforms
    with this limitation (for example iOS only suports Low Energy discovery),
    the discovery process will limit the search to the type which is supported.

    **Note:** Since Android 6.0 the ability to detect devices requires
    ACCESS_COARSE_LOCATION.

    **Note:** The Win32 backend currently does not support the Received Signal
    Strength Indicator (RSSI), as well as the Manufacturer Specific Data, or
    other data updates advertised by Bluetooth LE devices after discovery.
    """

    class DiscoveryMethod(enum.Flag):
        NoMethod: QBluetoothDeviceDiscoveryAgent = ...
        ClassicMethod: QBluetoothDeviceDiscoveryAgent = ...
        LowEnergyMethod: QBluetoothDeviceDiscoveryAgent = ...

    class Error(enum.Enum):
        NoError: QBluetoothDeviceDiscoveryAgent = ...
        InputOutputError: QBluetoothDeviceDiscoveryAgent = ...
        PoweredOffError: QBluetoothDeviceDiscoveryAgent = ...
        InvalidBluetoothAdapterError: QBluetoothDeviceDiscoveryAgent = ...
        UnsupportedPlatformError: QBluetoothDeviceDiscoveryAgent = ...
        UnsupportedDiscoveryMethod: QBluetoothDeviceDiscoveryAgent = ...
        LocationServiceTurnedOffError: QBluetoothDeviceDiscoveryAgent = ...
        UnknownError: QBluetoothDeviceDiscoveryAgent = ...

    @typing.overload
    def __init__(self, parent: typing.Optional[QtCore.QObject] = ...) -> None:
        """
        https://doc.qt.io/qt-6/qbluetoothdevicediscoveryagent.html#QBluetoothDev
        iceDiscoveryAgent

        **QBluetoothDeviceDiscoveryAgent::QBluetoothDeviceDiscoveryAgent(QObject
        * parent = nullptr)**

        Constructs a new Bluetooth device discovery agent with parent
        **parent**.
        """
        ...

    @typing.overload
    def __init__(
        self,
        deviceAdapter: QBluetoothAddress,
        parent: typing.Optional[QtCore.QObject] = ...,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qbluetoothdevicediscoveryagent.html#QBluetoothDev
        iceDiscoveryAgent-1

        **QBluetoothDeviceDiscoveryAgent::QBluetoothDeviceDiscoveryAgent(const
        QBluetoothAddress & deviceAdapter , QObject * parent = nullptr)**

        Constructs a new Bluetooth device discovery agent with **parent**.

        It uses **deviceAdapter** for the device search. If **deviceAdapter** is
        default constructed the resulting QBluetoothDeviceDiscoveryAgent object
        will use the local default Bluetooth adapter.

        If a **deviceAdapter** is specified that is not a local adapter
        **error** () will be set to **InvalidBluetoothAdapterError** . Therefore
        it is recommended to test the error flag immediately after using this
        constructor.

        **See also** **error** ().
        """
        ...

    @staticmethod
    def supportedDiscoveryMethods() -> "QBluetoothDeviceDiscoveryAgent.DiscoveryMethod":
        """
        https://doc.qt.io/qt-6/qbluetoothdevicediscoveryagent.html#supportedDisc
        overyMethods

        **[static, since 5.8] QBluetoothDeviceDiscoveryAgent::DiscoveryMethods
        QBluetoothDeviceDiscoveryAgent::supportedDiscoveryMethods()**

        This function returns the discovery methods supported by the current
        platform. It can be used to limit the scope of the device discovery.

        This function was introduced in Qt 5.8.
        """
        ...

    def lowEnergyDiscoveryTimeout(self) -> int:
        """
        https://doc.qt.io/qt-6/qbluetoothdevicediscoveryagent.html#lowEnergyDisc
        overyTimeout

        **[since 5.8] int
        QBluetoothDeviceDiscoveryAgent::lowEnergyDiscoveryTimeout() const**

        Returns a timeout in milliseconds that is applied to the Bluetooth Low
        Energy device search. A value of `-1` implies that the platform does not
        support this property and the timeout for the device search cannot be
        adjusted. A return value of `0` implies a never-ending search which must
        be manually stopped via **stop** ().

        This function was introduced in Qt 5.8.

        **See also** **setLowEnergyDiscoveryTimeout** ().
        """
        ...

    def setLowEnergyDiscoveryTimeout(self, msTimeout: int) -> None:
        """
        https://doc.qt.io/qt-6/qbluetoothdevicediscoveryagent.html#setLowEnergyD
        iscoveryTimeout

        **[since 5.8] void
        QBluetoothDeviceDiscoveryAgent::setLowEnergyDiscoveryTimeout(int timeout
        )**

        Sets the maximum search time for Bluetooth Low Energy device search to
        **timeout** in milliseconds. If **timeout** is `0` the discovery runs
        until **stop** () is called.

        This reflects the fact that the discovery process for Bluetooth Low
        Energy devices is mostly open ended. The platform continues to look for
        more devices until the search is manually stopped. The timeout ensures
        that the search is aborted after **timeout** milliseconds. Of course, it
        is still possible to manually abort the discovery by calling **stop**
        ().

        The new timeout value does not take effect until the device search is
        restarted. In addition the timeout does not affect the classic Bluetooth
        device search. Depending on the platform the classic search may add more
        time to the total discovery process beyond **timeout**.

        This function was introduced in Qt 5.8.

        **See also** **lowEnergyDiscoveryTimeout** ().
        """
        ...

    def stop(self) -> None:
        """
        https://doc.qt.io/qt-6/qbluetoothdevicediscoveryagent.html#stop

        **[slot] void QBluetoothDeviceDiscoveryAgent::stop()**

        Stops Bluetooth device discovery. The cancel() signal is emitted once
        the device discovery is canceled. **start** () maybe called before the
        cancel signal is received. Once **start** () has been called the cancel
        signal from the prior discovery will be discarded.
        """
        ...

    @typing.overload
    def start(self) -> None:
        """
        https://doc.qt.io/qt-6/qbluetoothdevicediscoveryagent.html#start

        **[slot] void QBluetoothDeviceDiscoveryAgent::start()**

        Starts Bluetooth device discovery, if it is not already started.

        The **deviceDiscovered** () signal is emitted as each device is
        discovered. The **finished** () signal is emitted once device discovery
        is complete. The discovery utilizes the maximum set of supported
        discovery methods on the platform.

        **See also** **supportedDiscoveryMethods** ().
        """
        ...

    @typing.overload
    def start(self, method: "QBluetoothDeviceDiscoveryAgent.DiscoveryMethod") -> None:
        """
        https://doc.qt.io/qt-6/qbluetoothdevicediscoveryagent.html#start-1

        **[slot, since 5.8] void QBluetoothDeviceDiscoveryAgent::start(QBluetoot
        hDeviceDiscoveryAgent::DiscoveryMethods methods )**

        Starts Bluetooth device discovery, if it is not already started and the
        provided **methods** are supported. The discovery **methods** limit the
        scope of the device search. For example, if the target service or device
        is a Bluetooth Low Energy device, this function could be used to limit
        the search to Bluetooth Low Energy devices and thereby reduces the
        discovery time significantly.

        **Note:** **methods** only determines the type of discovery and does not
        imply the filtering of the results. For example, the search may still
        contain classic bluetooth devices despite **methods** being set to
        **LowEnergyMethod**  only. This may happen due to previously cached
        search results which may be incorporated into the search results.

        This function was introduced in Qt 5.8.
        """
        ...

    def discoveredDevices(self) -> typing.List["QBluetoothDeviceInfo"]:
        """
        https://doc.qt.io/qt-6/qbluetoothdevicediscoveryagent.html#discoveredDev
        ices

        **QList<QBluetoothDeviceInfo>
        QBluetoothDeviceDiscoveryAgent::discoveredDevices() const**

        Returns a list of all discovered Bluetooth devices.
        """
        ...

    def errorString(self) -> str:
        """
        https://doc.qt.io/qt-6/qbluetoothdevicediscoveryagent.html#errorString

        **QString QBluetoothDeviceDiscoveryAgent::errorString() const**

        Returns a human-readable description of the last error.
        """
        ...

    def error(self) -> "QBluetoothDeviceDiscoveryAgent.Error":
        """
        https://doc.qt.io/qt-6/qbluetoothdevicediscoveryagent.html#error

        **QBluetoothDeviceDiscoveryAgent::Error
        QBluetoothDeviceDiscoveryAgent::error() const**

        Returns the last error.
        """
        ...

    def isActive(self) -> bool:
        """
        https://doc.qt.io/qt-6/qbluetoothdevicediscoveryagent.html#isActive

        **bool QBluetoothDeviceDiscoveryAgent::isActive() const**

        Returns true if the agent is currently discovering Bluetooth devices,
        otherwise returns false.
        """
        ...

    @property
    def canceled(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qbluetoothdevicediscoveryagent.html#canceled

        **[signal] void QBluetoothDeviceDiscoveryAgent::canceled()**

        This signal is emitted when device discovery is aborted by a call to
        **stop** ().
        """
        ...

    @property
    def deviceDiscovered(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qbluetoothdevicediscoveryagent.html#deviceDiscove
        red

        **[signal] void QBluetoothDeviceDiscoveryAgent::deviceDiscovered(const
        QBluetoothDeviceInfo & info )**

        This signal is emitted when the Bluetooth device described by **info**
        is discovered.

        The signal is emitted as soon as the most important device information
        has been collected. However, as long as the **finished** () signal has
        not been emitted the information collection continues even for already
        discovered devices. This is particularly true for signal strength
        information (RSSI) and manufacturer data updates. If the use case
        requires continuous manufacturer data or RSSI updates it is advisable to
        retrieve the device information via **discoveredDevices** () once the
        discovery has finished or listen to the **deviceUpdated** () signal.

        If **lowEnergyDiscoveryTimeout** () is larger than 0 the signal is only
        ever emitted when at least one attribute of **info** changes. This
        reflects the desire to receive updates as more precise information
        becomes available. The exception to this behavior is the case when
        **lowEnergyDiscoveryTimeout**  is set to `0`. A timeout of `0` expresses
        the desire to monitor the appearance and disappearance of Low Energy
        devices over time. Under this condition the deviceDiscovered() signal is
        emitted even if **info** has not changed since the last signal emission.

        **See also** **QBluetoothDeviceInfo::rssi** () and
        **lowEnergyDiscoveryTimeout** ().
        """
        ...

    @property
    def deviceUpdated(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qbluetoothdevicediscoveryagent.html#deviceUpdated

        **[signal] void QBluetoothDeviceDiscoveryAgent::deviceUpdated(const
        QBluetoothDeviceInfo & info , QBluetoothDeviceInfo::Fields updatedFields
        )**

        This signal is emitted when the agent receives additional information
        about the Bluetooth device described by **info**. The **updatedFields**
        flags tell which information has been updated.

        During discovery, some information can change dynamically, such as
        **signal strength**  and **manufacturerData** . This signal informs you
        that if your application is displaying this data, it can be updated,
        rather than waiting until the discovery has finished.

        **See also** **QBluetoothDeviceInfo::rssi** () and
        **lowEnergyDiscoveryTimeout** ().
        """
        ...

    @property
    def errorOccurred(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qbluetoothdevicediscoveryagent.html#errorOccurred

        **[signal, since 6.2] void QBluetoothDeviceDiscoveryAgent::errorOccurred
        (QBluetoothDeviceDiscoveryAgent::Error error )**

        This signal is emitted when an **error** occurs during Bluetooth device
        discovery. The **error** parameter describes the error that occurred.

        This function was introduced in Qt 6.2.

        **See also** **error** () and **errorString** ().
        """
        ...

    @property
    def finished(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qbluetoothdevicediscoveryagent.html#finished

        **[signal] void QBluetoothDeviceDiscoveryAgent::finished()**

        This signal is emitted when Bluetooth device discovery completes. The
        signal is not going to be emitted if the device discovery finishes with
        an error.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
from PyQt6.QtRemoteObjects import *


class QRemoteObjectDynamicReplica(QRemoteObjectReplica):
    """
    https://doc.qt.io/qt-6/qremoteobjectdynamicreplica.html

    **Detailed Description**

    There are generated replicas (replicas having the header files produced by
    the **Replica Compiler** ), and dynamic replicas, that are generated on-the-
    fly. This is the class for the dynamic type of replica.

    When the connection to the **Source**  object is made, the initialization
    step passes the current property values (see **Replica Initialization** ).
    In a DynamicReplica, the property/signal/slot details are also sent,
    allowing the replica object to be created on-the-fly. This can be convenient
    in QML or scripting, but has two primary disadvantages. First, the object is
    in effect "empty" until it is successfully initialized by the **Source** .
    Second, in C++, calls must be made using **QMetaObject::invokeMethod** (),
    as the moc generated lookup will not be available.

    This class does not have a public constructor. It can only be instantiated
    by using the dynamic **QRemoteObjectNode::acquire**  method.
    """

    ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import PyQt6.sip
from PyQt6 import QtCore
from PyQt6.QtDBus import *
import enum


class QDBusConnectionInterface(QDBusAbstractInterface):
    """
    https://doc.qt.io/qt-6/qdbusconnectioninterface.html

    **Detailed Description**

    The D-Bus bus server daemon provides one special interface
    `org.freedesktop.DBus` that allows clients to access certain properties of
    the bus, such as the current list of clients connected. The
    QDBusConnectionInterface class provides access to that interface.

    The most common uses of this class are to register and unregister service
    names on the bus using the **registerService** () and **unregisterService**
    () functions, query about existing names using the **isServiceRegistered**
    (), **registeredServiceNames** () and **serviceOwner** () functions, and to
    receive notification that a client has registered or de-registered through
    the **serviceRegistered** (), **serviceUnregistered** () and
    serviceOwnerChanged() signals.
    """

    class RegisterServiceReply(enum.Enum):
        ServiceNotRegistered: QDBusConnectionInterface = ...
        ServiceRegistered: QDBusConnectionInterface = ...
        ServiceQueued: QDBusConnectionInterface = ...

    class ServiceReplacementOptions(enum.Enum):
        DontAllowReplacement: QDBusConnectionInterface = ...
        AllowReplacement: QDBusConnectionInterface = ...

    class ServiceQueueOptions(enum.Enum):
        DontQueueService: QDBusConnectionInterface = ...
        QueueService: QDBusConnectionInterface = ...
        ReplaceExistingService: QDBusConnectionInterface = ...

    def disconnectNotify(self, a0: QtCore.QMetaMethod) -> None:
        ...

    def connectNotify(self, a0: QtCore.QMetaMethod) -> None:
        ...

    def serviceOwnerChanged(self, name: str, oldOwner: str, newOwner: str) -> None:
        ...

    def startService(self, name: str) -> QDBusReply:
        """
        https://doc.qt.io/qt-6/qdbusconnectioninterface.html#startService

        **[slot] QDBusReply<void> QDBusConnectionInterface::startService(const
        QString & name )**

        Requests that the bus start the service given by the name **name**.
        """
        ...

    def serviceUid(self, serviceName: str) -> QDBusReply:
        """
        https://doc.qt.io/qt-6/qdbusconnectioninterface.html#serviceUid

        **[slot] QDBusReply<uint> QDBusConnectionInterface::serviceUid(const
        QString & serviceName ) const**

        Returns the Unix User ID (UID) for the process currently holding the bus
        service **serviceName**.
        """
        ...

    def servicePid(self, serviceName: str) -> QDBusReply:
        """
        https://doc.qt.io/qt-6/qdbusconnectioninterface.html#servicePid

        **[slot] QDBusReply<uint> QDBusConnectionInterface::servicePid(const
        QString & serviceName ) const**

        Returns the Unix Process ID (PID) for the process currently holding the
        bus service **serviceName**.
        """
        ...

    def registerService(
        self,
        serviceName: str,
        qoption: "QDBusConnectionInterface.ServiceQueueOptions" = ...,
        roption: "QDBusConnectionInterface.ServiceReplacementOptions" = ...,
    ) -> QDBusReply:
        """
        https://doc.qt.io/qt-6/qdbusconnectioninterface.html#registerService

        **[slot] QDBusReply<QDBusConnectionInterface::RegisterServiceReply>
        QDBusConnectionInterface::registerService(const QString & serviceName ,
        QDBusConnectionInterface::ServiceQueueOptions qoption =
        DontQueueService, QDBusConnectionInterface::ServiceReplacementOptions
        roption = DontAllowReplacement)**

        Requests to register the service name **serviceName** on the bus. The
        **qoption** flag specifies how the D-Bus server should behave if
        **serviceName** is already registered. The **roption** flag specifies if
        the server should allow another application to replace our registered
        name.

        If the service registration succeeds, the **serviceRegistered** ()
        signal will be emitted. If we are placed in queue, the signal will be
        emitted when we obtain the name. If **roption** is **AllowReplacement**
        , the **serviceUnregistered** () signal will be emitted if another
        application replaces this one.

        **See also** **unregisterService** ().
        """
        ...

    def unregisterService(self, serviceName: str) -> QDBusReply:
        """
        https://doc.qt.io/qt-6/qdbusconnectioninterface.html#unregisterService

        **[slot] QDBusReply<bool>
        QDBusConnectionInterface::unregisterService(const QString & serviceName
        )**

        Releases the claim on the bus service name **serviceName** , that had
        been previously registered with **registerService** (). If this
        application had ownership of the name, it will be released for other
        applications to claim. If it only had the name queued, it gives up its
        position in the queue.
        """
        ...

    def serviceOwner(self, name: str) -> QDBusReply:
        """
        https://doc.qt.io/qt-6/qdbusconnectioninterface.html#serviceOwner

        **[slot] QDBusReply<QString>
        QDBusConnectionInterface::serviceOwner(const QString & name ) const**

        Returns the unique connection name of the primary owner of the name
        **name**. If the requested name doesn't have an owner, returns a
        `org.freedesktop.DBus.Error.NameHasNoOwner` error.
        """
        ...

    def isServiceRegistered(self, serviceName: str) -> QDBusReply:
        """
        https://doc.qt.io/qt-6/qdbusconnectioninterface.html#isServiceRegistered

        **[slot] QDBusReply<bool>
        QDBusConnectionInterface::isServiceRegistered(const QString &
        serviceName ) const**

        Returns `true` if the service name **serviceName** has is currently
        registered.
        """
        ...

    def activatableServiceNames(self) -> QDBusReply:
        """
        https://doc.qt.io/qt-6/qdbusconnectioninterface.html#activatableServiceN
        ames-prop

        **[read-only, since 5.14] activatableServiceNames : const
        QDBusReply<QStringList>**

        holds the activatable service names

        Lists all names that can be activated on the bus.

        This property was introduced in Qt 5.14.

        **Access functions:**

        QDBusReply<QStringList> **activatableServiceNames** () const
        """
        ...

    def registeredServiceNames(self) -> QDBusReply:
        """
        https://doc.qt.io/qt-6/qdbusconnectioninterface.html#registeredServiceNa
        mes-prop

        **[read-only] registeredServiceNames : const QDBusReply<QStringList>**

        holds the registered service names

        Lists all names currently registered on the bus.

        **Access functions:**

        QDBusReply<QStringList> **registeredServiceNames** () const

        **Member Function Documentation**
        """
        ...

    @property
    def callWithCallbackFailed(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qdbusconnectioninterface.html#callWithCallbackFai
        led

        **[signal] void QDBusConnectionInterface::callWithCallbackFailed(const
        QDBusError & error , const QDBusMessage & call )**

        This signal is emitted when there is an error during a
        **QDBusConnection::callWithCallback** (). **error** specifies the error.
        **call** is the message that couldn't be delivered.

        **See also** **QDBusConnection::callWithCallback** ().
        """
        ...

    @property
    def serviceRegistered(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qdbusconnectioninterface.html#serviceRegistered

        **[signal] void QDBusConnectionInterface::serviceRegistered(const
        QString & service )**

        This signal is emitted by the D-Bus server when the bus service name
        (unique connection name or well-known service name) given by **service**
        is acquired by this application.

        Acquisition happens after this application has requested a name using
        **registerService** ().
        """
        ...

    @property
    def serviceUnregistered(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qdbusconnectioninterface.html#serviceUnregistered

        **[signal] void QDBusConnectionInterface::serviceUnregistered(const
        QString & service )**

        This signal is emitted by the D-Bus server when this application loses
        ownership of the bus service name given by **service**.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip


class QDBusObjectPath(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qdbusobjectpath.html

    **Detailed Description**

    **See also** **The Qt D-Bus Type System** .
    """

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qdbusobjectpath.html#QDBusObjectPath

        **QDBusObjectPath::QDBusObjectPath()**

        Constructs a new object path.
        """
        ...

    @typing.overload
    def __init__(self, objectPath: str) -> None:
        """
        https://doc.qt.io/qt-6/qdbusobjectpath.html#QDBusObjectPath-1

        **QDBusObjectPath::QDBusObjectPath(const char * path )**

        Constructs a new object path from the given **path**.

        **See also** **setPath** ().
        """
        ...

    @typing.overload
    def __init__(self, a0: "QDBusObjectPath") -> None:
        """
        https://doc.qt.io/qt-6/qdbusobjectpath.html#QDBusObjectPath-2

        **QDBusObjectPath::QDBusObjectPath(QLatin1String path )**

        Constructs a new object path from the given **path**.
        """
        ...

    def swap(self, other: "QDBusObjectPath") -> None:
        """
        https://doc.qt.io/qt-6/qdbusobjectpath.html#swap

        **void QDBusObjectPath::swap(QDBusObjectPath & other )**

        Swaps this **QDBusObjectPath**  instance with **other**.
        """
        ...

    def __hash__(self) -> int:
        ...

    def setPath(self, objectPath: str) -> None:
        """
        https://doc.qt.io/qt-6/qdbusobjectpath.html#setPath

        **void QDBusObjectPath::setPath(const QString & path )**

        Assigns the value of the given **path** to this object path.

        **See also** **path** ().
        """
        ...

    def path(self) -> str:
        """
        https://doc.qt.io/qt-6/qdbusobjectpath.html#path

        **QString QDBusObjectPath::path() const**

        Returns this object path.

        **See also** **setPath** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
from PyQt6.QtWidgets import *


class QVBoxLayout(QBoxLayout):
    """
    https://doc.qt.io/qt-6/qvboxlayout.html

    **Detailed Description**

    This class is used to construct vertical box layout objects. See
    **QBoxLayout**  for details.

    The simplest use of the class is like this:

    **QWidget**  *window = new **QWidget** ;
            **QPushButton**  *button1 =
    new **QPushButton** ("One");
            **QPushButton**  *button2 = new
    **QPushButton** ("Two");
            **QPushButton**  *button3 = new
    **QPushButton** ("Three");
            **QPushButton**  *button4 = new
    **QPushButton** ("Four");
            **QPushButton**  *button5 = new
    **QPushButton** ("Five");

            **QVBoxLayout**  *layout = new
    **QVBoxLayout** (window);
            layout->addWidget(button1);
    layout->addWidget(button2);
            layout->addWidget(button3);
    layout->addWidget(button4);
            layout->addWidget(button5);
    window->show();

    First, we create the widgets we want to add to the layout. Then, we create
    the QVBoxLayout object, setting `window` as parent by passing it in the
    constructor; next we add the widgets to the layout. `window` will be the
    parent of the widgets that are added to the layout.

    If you don't pass a parent `window` to the constructor, you can at a later
    point use **QWidget::setLayout** () to install the QVBoxLayout object onto
    `window`. At that point, the widgets in the layout are reparented to have
    `window` as their parent.

    ![Horizontal box layout with five child widgets](images/qvboxlayout-
    with-5-children.png)

    **See also** **QHBoxLayout** , **QGridLayout** , **QStackedLayout** ,
    **Layout Management** , and **Basic Layouts Example** .
    """

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qvboxlayout.html#QVBoxLayout

        **QVBoxLayout::QVBoxLayout()**

        Constructs a new vertical box. You must add it to another layout.
        """
        ...

    @typing.overload
    def __init__(self, parent: QWidget) -> None:
        """
        https://doc.qt.io/qt-6/qvboxlayout.html#QVBoxLayout-1

        **QVBoxLayout::QVBoxLayout(QWidget * parent )**

        Constructs a new top-level vertical box with parent **parent**.

        The layout is set directly as the top-level layout for **parent**. There
        can be only one top-level layout for a widget. It is returned by
        **QWidget::layout** ().

        **See also** **QWidget::setLayout** ().
        """
        ...
